pub struct AnswerRecords { /* private fields */ }answer-records only.Expand description
Implements a client for the Dialogflow API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
async fn sample(
project_id: &str,
) -> anyhow::Result<()> {
let client = AnswerRecords::builder().build().await?;
let mut list = client.list_answer_records()
.set_parent(format!("projects/{project_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Service Description
Service for managing AnswerRecords.
Configuration
To configure AnswerRecords use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://dialogflow.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
AnswerRecords holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap AnswerRecords in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl AnswerRecords
impl AnswerRecords
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for AnswerRecords.
let client = AnswerRecords::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: AnswerRecords + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: AnswerRecords + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn list_answer_records(&self) -> ListAnswerRecords
pub fn list_answer_records(&self) -> ListAnswerRecords
Returns the list of all answer records in the specified project in reverse chronological order.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &AnswerRecords, project_id: &str
) -> Result<()> {
let mut list = client.list_answer_records()
.set_parent(format!("projects/{project_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn update_answer_record(&self) -> UpdateAnswerRecord
pub fn update_answer_record(&self) -> UpdateAnswerRecord
Updates the specified answer record.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_dialogflow_v2::model::AnswerRecord;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &AnswerRecords, project_id: &str, answer_record_id: &str
) -> Result<()> {
let response = client.update_answer_record()
.set_answer_record(
AnswerRecord::new().set_name(format!("projects/{project_id}/answerRecords/{answer_record_id}"))/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
This method lists locations based on the resource scope provided in the [ListLocationsRequest.name] field:
- Global locations: If
nameis empty, the method lists the public locations available to all projects. * Project-specific locations: Ifnamefollows the formatprojects/{project}, the method lists locations visible to that specific project. This includes public, private, or other project-specific locations enabled for the project.
For gRPC and client library implementations, the resource name is
passed as the name field. For direct service calls, the resource
name is
incorporated into the request path based on the specific service
implementation and version.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &AnswerRecords
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &AnswerRecords
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &AnswerRecords
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &AnswerRecords
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &AnswerRecords
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for AnswerRecords
impl Clone for AnswerRecords
Sourcefn clone(&self) -> AnswerRecords
fn clone(&self) -> AnswerRecords
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more