pub struct ConversationDatasets { /* private fields */ }conversation-datasets only.Expand description
Implements a client for the Dialogflow API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = ConversationDatasets::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_conversation_datasets()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Conversation datasets.
Conversation datasets contain raw conversation files and their customizable metadata that can be used for model training.
Configuration
To configure ConversationDatasets use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://dialogflow.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
ConversationDatasets holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap ConversationDatasets in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl ConversationDatasets
impl ConversationDatasets
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for ConversationDatasets.
let client = ConversationDatasets::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: ConversationDatasets + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: ConversationDatasets + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn create_conversation_dataset(&self) -> CreateConversationDataset
pub fn create_conversation_dataset(&self) -> CreateConversationDataset
Creates a new conversation dataset.
This method is a long-running
operation.
The returned Operation type has the following method-specific fields:
metadata: CreateConversationDatasetOperationMetadataresponse: ConversationDataset
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_dialogflow_v2::model::ConversationDataset;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &ConversationDatasets, parent: &str
) -> Result<()> {
let response = client.create_conversation_dataset()
.set_parent(parent)
.set_conversation_dataset(
ConversationDataset::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_conversation_dataset(&self) -> GetConversationDataset
pub fn get_conversation_dataset(&self) -> GetConversationDataset
Retrieves the specified conversation dataset.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &ConversationDatasets, name: &str
) -> Result<()> {
let response = client.get_conversation_dataset()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_conversation_datasets(&self) -> ListConversationDatasets
pub fn list_conversation_datasets(&self) -> ListConversationDatasets
Returns the list of all conversation datasets in the specified project and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &ConversationDatasets, parent: &str
) -> Result<()> {
let mut list = client.list_conversation_datasets()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn delete_conversation_dataset(&self) -> DeleteConversationDataset
pub fn delete_conversation_dataset(&self) -> DeleteConversationDataset
Deletes the specified conversation dataset.
This method is a long-running
operation.
The returned Operation type has the following method-specific fields:
metadata: DeleteConversationDatasetOperationMetadataresponse: An Empty message
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &ConversationDatasets, name: &str
) -> Result<()> {
client.delete_conversation_dataset()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn import_conversation_data(&self) -> ImportConversationData
pub fn import_conversation_data(&self) -> ImportConversationData
Import data into the specified conversation dataset. Note that it is not allowed to import data to a conversation dataset that already has data in it.
This method is a long-running
operation.
The returned Operation type has the following method-specific fields:
metadata: ImportConversationDataOperationMetadataresponse: ImportConversationDataOperationResponse
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &ConversationDatasets
) -> Result<()> {
let response = client.import_conversation_data()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
This method lists locations based on the resource scope provided in the [ListLocationsRequest.name] field:
- Global locations: If
nameis empty, the method lists the public locations available to all projects. * Project-specific locations: Ifnamefollows the formatprojects/{project}, the method lists locations visible to that specific project. This includes public, private, or other project-specific locations enabled for the project.
For gRPC and client library implementations, the resource name is
passed as the name field. For direct service calls, the resource
name is
incorporated into the request path based on the specific service
implementation and version.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &ConversationDatasets
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &ConversationDatasets
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &ConversationDatasets
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &ConversationDatasets
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &ConversationDatasets
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for ConversationDatasets
impl Clone for ConversationDatasets
Sourcefn clone(&self) -> ConversationDatasets
fn clone(&self) -> ConversationDatasets
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more