Conversations

Struct Conversations 

pub struct Conversations { /* private fields */ }
Available on crate feature conversations only.
Implements a client for the Dialogflow API.

Example

use google_cloud_gax::paginator::ItemPaginator as _;
    let client = Conversations::builder().build().await?;
    let parent = "parent_value";
    let mut list = client.list_conversations()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }

Service Description

Service for managing Conversations.

Configuration

To configure Conversations use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

  • with_endpoint(): by default this client uses the global default endpoint (https://dialogflow.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default.
  • with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.

Pooling and Cloning

Conversations holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap Conversations in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl Conversations

pub fn builder() -> ClientBuilder

Returns a builder for Conversations.

let client = Conversations::builder().build().await?;
pub fn from_stub<T>(stub: T) -> Self
where T: Conversations + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn create_conversation(&self) -> CreateConversation

Creates a new conversation. Conversations are auto-completed after 24 hours.

Conversation Lifecycle: There are two stages during a conversation: Automated Agent Stage and Assist Stage.

For Automated Agent Stage, there will be a dialogflow agent responding to user queries.

For Assist Stage, there’s no dialogflow agent responding to user queries. But we will provide suggestions which are generated from conversation.

If Conversation.conversation_profile is configured for a dialogflow agent, conversation will start from Automated Agent Stage, otherwise, it will start from Assist Stage. And during Automated Agent Stage, once an Intent with Intent.live_agent_handoff is triggered, conversation will transfer to Assist Stage.

Example
use google_cloud_dialogflow_v2::model::Conversation;
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Conversations, parent: &str
) -> Result<()> {
    let response = client.create_conversation()
        .set_parent(parent)
        .set_conversation_id("conversation_id_value")
        .set_conversation(
            Conversation::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_conversations(&self) -> ListConversations

Returns the list of all conversations in the specified project.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Conversations, parent: &str
) -> Result<()> {
    let mut list = client.list_conversations()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_conversation(&self) -> GetConversation

Retrieves the specific conversation.

Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Conversations, name: &str
) -> Result<()> {
    let response = client.get_conversation()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn complete_conversation(&self) -> CompleteConversation

Completes the specified conversation. Finished conversations are purged from the database after 30 days.

Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Conversations
) -> Result<()> {
    let response = client.complete_conversation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn ingest_context_references(&self) -> IngestContextReferences

Data ingestion API. Ingests context references for an existing conversation.

Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Conversations
) -> Result<()> {
    let response = client.ingest_context_references()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_messages(&self) -> ListMessages

Lists messages that belong to a given conversation. messages are ordered by create_time in descending order. To fetch updates without duplication, send request with filter create_time_epoch_microseconds > [first item's create_time of previous request] and empty page_token.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Conversations, parent: &str
) -> Result<()> {
    let mut list = client.list_messages()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn suggest_conversation_summary(&self) -> SuggestConversationSummary

Suggests summary for a conversation based on specific historical messages. The range of the messages to be used for summary can be specified in the request.

Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Conversations
) -> Result<()> {
    let response = client.suggest_conversation_summary()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn generate_stateless_summary(&self) -> GenerateStatelessSummary

Generates and returns a summary for a conversation that does not have a resource created for it.

Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Conversations
) -> Result<()> {
    let response = client.generate_stateless_summary()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn generate_stateless_suggestion(&self) -> GenerateStatelessSuggestion

Generates and returns a suggestion for a conversation that does not have a resource created for it.

Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Conversations
) -> Result<()> {
    let response = client.generate_stateless_suggestion()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn search_knowledge(&self) -> SearchKnowledge

Get answers for the given query based on knowledge documents.

Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Conversations
) -> Result<()> {
    let response = client.search_knowledge()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn generate_suggestions(&self) -> GenerateSuggestions

Generates all the suggestions using generators configured in the conversation profile. A generator is used only if its trigger event is matched.

Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Conversations
) -> Result<()> {
    let response = client.generate_suggestions()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_locations(&self) -> ListLocations

Lists information about the supported locations for this service.

This method lists locations based on the resource scope provided in the [ListLocationsRequest.name] field:

  • Global locations: If name is empty, the method lists the public locations available to all projects. * Project-specific locations: If name follows the format projects/{project}, the method lists locations visible to that specific project. This includes public, private, or other project-specific locations enabled for the project.

For gRPC and client library implementations, the resource name is passed as the name field. For direct service calls, the resource name is incorporated into the request path based on the specific service implementation and version.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Conversations
) -> Result<()> {
    let mut list = client.list_locations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_location(&self) -> GetLocation

Gets information about a location.

Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Conversations
) -> Result<()> {
    let response = client.get_location()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_operations(&self) -> ListOperations

Provides the Operations service functionality in this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Conversations
) -> Result<()> {
    let mut list = client.list_operations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_operation(&self) -> GetOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Conversations
) -> Result<()> {
    let response = client.get_operation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn cancel_operation(&self) -> CancelOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Conversations
) -> Result<()> {
    client.cancel_operation()
        /* set fields */
        .send().await?;
    Ok(())
}