pub struct EntityTypes { /* private fields */ }entity-types only.Expand description
Implements a client for the Dialogflow API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = EntityTypes::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_entity_types()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Service for managing EntityTypes.
Configuration
To configure EntityTypes use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://dialogflow.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
EntityTypes holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap EntityTypes in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl EntityTypes
impl EntityTypes
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for EntityTypes.
let client = EntityTypes::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: EntityTypes + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: EntityTypes + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn list_entity_types(&self) -> ListEntityTypes
pub fn list_entity_types(&self) -> ListEntityTypes
Returns the list of all entity types in the specified agent.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &EntityTypes, parent: &str
) -> Result<()> {
let mut list = client.list_entity_types()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_entity_type(&self) -> GetEntityType
pub fn get_entity_type(&self) -> GetEntityType
Retrieves the specified entity type.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &EntityTypes, name: &str
) -> Result<()> {
let response = client.get_entity_type()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_entity_type(&self) -> CreateEntityType
pub fn create_entity_type(&self) -> CreateEntityType
Creates an entity type in the specified agent.
Note: You should always train an agent prior to sending it queries. See the training documentation.
Example
use google_cloud_dialogflow_v2::model::EntityType;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &EntityTypes, parent: &str
) -> Result<()> {
let response = client.create_entity_type()
.set_parent(parent)
.set_entity_type(
EntityType::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_entity_type(&self) -> UpdateEntityType
pub fn update_entity_type(&self) -> UpdateEntityType
Updates the specified entity type.
Note: You should always train an agent prior to sending it queries. See the training documentation.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_dialogflow_v2::model::EntityType;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &EntityTypes, name: &str
) -> Result<()> {
let response = client.update_entity_type()
.set_entity_type(
EntityType::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_entity_type(&self) -> DeleteEntityType
pub fn delete_entity_type(&self) -> DeleteEntityType
Deletes the specified entity type.
Note: You should always train an agent prior to sending it queries. See the training documentation.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &EntityTypes, name: &str
) -> Result<()> {
client.delete_entity_type()
.set_name(name)
.send().await?;
Ok(())
}Sourcepub fn batch_update_entity_types(&self) -> BatchUpdateEntityTypes
pub fn batch_update_entity_types(&self) -> BatchUpdateEntityTypes
Updates/Creates multiple entity types in the specified agent.
This method is a long-running
operation.
The returned Operation type has the following method-specific fields:
metadata: An empty Struct messageresponse: BatchUpdateEntityTypesResponse
Note: You should always train an agent prior to sending it queries. See the training documentation.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &EntityTypes
) -> Result<()> {
let response = client.batch_update_entity_types()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn batch_delete_entity_types(&self) -> BatchDeleteEntityTypes
pub fn batch_delete_entity_types(&self) -> BatchDeleteEntityTypes
Deletes entity types in the specified agent.
This method is a long-running
operation.
The returned Operation type has the following method-specific fields:
metadata: An empty Struct messageresponse: An Empty message
Note: You should always train an agent prior to sending it queries. See the training documentation.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &EntityTypes
) -> Result<()> {
client.batch_delete_entity_types()
/* set fields */
.poller().until_done().await?;
Ok(())
}Sourcepub fn batch_create_entities(&self) -> BatchCreateEntities
pub fn batch_create_entities(&self) -> BatchCreateEntities
Creates multiple new entities in the specified entity type.
This method is a long-running
operation.
The returned Operation type has the following method-specific fields:
metadata: An empty Struct messageresponse: An Empty message
Note: You should always train an agent prior to sending it queries. See the training documentation.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &EntityTypes
) -> Result<()> {
client.batch_create_entities()
/* set fields */
.poller().until_done().await?;
Ok(())
}Sourcepub fn batch_update_entities(&self) -> BatchUpdateEntities
pub fn batch_update_entities(&self) -> BatchUpdateEntities
Updates or creates multiple entities in the specified entity type. This method does not affect entities in the entity type that aren’t explicitly specified in the request.
This method is a long-running
operation.
The returned Operation type has the following method-specific fields:
metadata: An empty Struct messageresponse: An Empty message
Note: You should always train an agent prior to sending it queries. See the training documentation.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &EntityTypes
) -> Result<()> {
client.batch_update_entities()
/* set fields */
.poller().until_done().await?;
Ok(())
}Sourcepub fn batch_delete_entities(&self) -> BatchDeleteEntities
pub fn batch_delete_entities(&self) -> BatchDeleteEntities
Deletes entities in the specified entity type.
This method is a long-running
operation.
The returned Operation type has the following method-specific fields:
metadata: An empty Struct messageresponse: An Empty message
Note: You should always train an agent prior to sending it queries. See the training documentation.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &EntityTypes
) -> Result<()> {
client.batch_delete_entities()
/* set fields */
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
This method lists locations based on the resource scope provided in the [ListLocationsRequest.name] field:
- Global locations: If
nameis empty, the method lists the public locations available to all projects. * Project-specific locations: Ifnamefollows the formatprojects/{project}, the method lists locations visible to that specific project. This includes public, private, or other project-specific locations enabled for the project.
For gRPC and client library implementations, the resource name is
passed as the name field. For direct service calls, the resource
name is
incorporated into the request path based on the specific service
implementation and version.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &EntityTypes
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &EntityTypes
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &EntityTypes
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &EntityTypes
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &EntityTypes
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for EntityTypes
impl Clone for EntityTypes
Sourcefn clone(&self) -> EntityTypes
fn clone(&self) -> EntityTypes
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more