Environments

Struct Environments 

pub struct Environments { /* private fields */ }
Available on crate feature environments only.
Implements a client for the Dialogflow API.

Example

use google_cloud_gax::paginator::ItemPaginator as _;
    let client = Environments::builder().build().await?;
    let parent = "parent_value";
    let mut list = client.list_environments()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }

Service Description

Service for managing Environments.

Configuration

To configure Environments use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

  • with_endpoint(): by default this client uses the global default endpoint (https://dialogflow.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default.
  • with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.

Pooling and Cloning

Environments holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap Environments in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl Environments

pub fn builder() -> ClientBuilder

Returns a builder for Environments.

let client = Environments::builder().build().await?;
pub fn from_stub<T>(stub: T) -> Self
where T: Environments + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn list_environments(&self) -> ListEnvironments

Returns the list of all non-default environments of the specified agent.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Environments, parent: &str
) -> Result<()> {
    let mut list = client.list_environments()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_environment(&self) -> GetEnvironment

Retrieves the specified agent environment.

Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Environments, name: &str
) -> Result<()> {
    let response = client.get_environment()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_environment(&self) -> CreateEnvironment

Creates an agent environment.

Example
use google_cloud_dialogflow_v2::model::Environment;
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Environments, parent: &str
) -> Result<()> {
    let response = client.create_environment()
        .set_parent(parent)
        .set_environment_id("environment_id_value")
        .set_environment(
            Environment::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_environment(&self) -> UpdateEnvironment

Updates the specified agent environment.

This method allows you to deploy new agent versions into the environment. When an environment is pointed to a new agent version by setting environment.agent_version, the environment is temporarily set to the LOADING state. During that time, the environment continues serving the previous version of the agent. After the new agent version is done loading, the environment is set back to the RUNNING state. You can use “-” as Environment ID in environment name to update an agent version in the default environment. WARNING: this will negate all recent changes to the draft agent and can’t be undone. You may want to save the draft agent to a version before calling this method.

Example
use google_cloud_wkt::FieldMask;
use google_cloud_dialogflow_v2::model::Environment;
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Environments, name: &str
) -> Result<()> {
    let response = client.update_environment()
        .set_environment(
            Environment::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_environment(&self) -> DeleteEnvironment

Deletes the specified agent environment.

Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Environments, name: &str
) -> Result<()> {
    client.delete_environment()
        .set_name(name)
        .send().await?;
    Ok(())
}
pub fn get_environment_history(&self) -> GetEnvironmentHistory

Gets the history of the specified environment.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Environments
) -> Result<()> {
    let mut list = client.get_environment_history()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn list_locations(&self) -> ListLocations

Lists information about the supported locations for this service.

This method lists locations based on the resource scope provided in the [ListLocationsRequest.name] field:

  • Global locations: If name is empty, the method lists the public locations available to all projects. * Project-specific locations: If name follows the format projects/{project}, the method lists locations visible to that specific project. This includes public, private, or other project-specific locations enabled for the project.

For gRPC and client library implementations, the resource name is passed as the name field. For direct service calls, the resource name is incorporated into the request path based on the specific service implementation and version.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Environments
) -> Result<()> {
    let mut list = client.list_locations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_location(&self) -> GetLocation

Gets information about a location.

Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Environments
) -> Result<()> {
    let response = client.get_location()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_operations(&self) -> ListOperations

Provides the Operations service functionality in this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Environments
) -> Result<()> {
    let mut list = client.list_operations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_operation(&self) -> GetOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Environments
) -> Result<()> {
    let response = client.get_operation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn cancel_operation(&self) -> CancelOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
   client: &Environments
) -> Result<()> {
    client.cancel_operation()
        /* set fields */
        .send().await?;
    Ok(())
}