pub struct Generators { /* private fields */ }generators only.Expand description
Implements a client for the Dialogflow API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
async fn sample(
parent: &str,
) -> anyhow::Result<()> {
let client = Generators::builder().build().await?;
let mut list = client.list_generators()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Service Description
Generator Service for LLM powered Agent Assist. This service manages the configurations of user owned Generators, such as description, context and instruction, input/output format, etc. The generator resources will be used inside a conversation and will be triggered by TriggerEvent to query LLM for answers.
Configuration
To configure Generators use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://dialogflow.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
Generators holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap Generators in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl Generators
impl Generators
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for Generators.
let client = Generators::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: Generators + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: Generators + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn create_generator(&self) -> CreateGenerator
pub fn create_generator(&self) -> CreateGenerator
Creates a generator.
Example
use google_cloud_dialogflow_v2::model::Generator;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &Generators, parent: &str
) -> Result<()> {
let response = client.create_generator()
.set_parent(parent)
.set_generator_id("generator_id_value")
.set_generator(
Generator::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_generator(&self) -> GetGenerator
pub fn get_generator(&self) -> GetGenerator
Retrieves a generator.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &Generators, project_id: &str, location_id: &str, generator_id: &str
) -> Result<()> {
let response = client.get_generator()
.set_name(format!("projects/{project_id}/locations/{location_id}/generators/{generator_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_generators(&self) -> ListGenerators
pub fn list_generators(&self) -> ListGenerators
Lists generators.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &Generators, parent: &str
) -> Result<()> {
let mut list = client.list_generators()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn delete_generator(&self) -> DeleteGenerator
pub fn delete_generator(&self) -> DeleteGenerator
Deletes a generator.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &Generators, project_id: &str, location_id: &str, generator_id: &str
) -> Result<()> {
client.delete_generator()
.set_name(format!("projects/{project_id}/locations/{location_id}/generators/{generator_id}"))
.send().await?;
Ok(())
}Sourcepub fn update_generator(&self) -> UpdateGenerator
pub fn update_generator(&self) -> UpdateGenerator
Updates a generator.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_dialogflow_v2::model::Generator;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &Generators, project_id: &str, location_id: &str, generator_id: &str
) -> Result<()> {
let response = client.update_generator()
.set_generator(
Generator::new().set_name(format!("projects/{project_id}/locations/{location_id}/generators/{generator_id}"))/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
This method lists locations based on the resource scope provided in the [ListLocationsRequest.name] field:
- Global locations: If
nameis empty, the method lists the public locations available to all projects. * Project-specific locations: Ifnamefollows the formatprojects/{project}, the method lists locations visible to that specific project. This includes public, private, or other project-specific locations enabled for the project.
For gRPC and client library implementations, the resource name is
passed as the name field. For direct service calls, the resource
name is
incorporated into the request path based on the specific service
implementation and version.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &Generators
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &Generators
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &Generators
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &Generators
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &Generators
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for Generators
impl Clone for Generators
Sourcefn clone(&self) -> Generators
fn clone(&self) -> Generators
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more