pub struct KnowledgeBases { /* private fields */ }knowledge-bases only.Expand description
Implements a client for the Dialogflow API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = KnowledgeBases::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_knowledge_bases()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Service for managing KnowledgeBases.
Configuration
To configure KnowledgeBases use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://dialogflow.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
KnowledgeBases holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap KnowledgeBases in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl KnowledgeBases
impl KnowledgeBases
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for KnowledgeBases.
let client = KnowledgeBases::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: KnowledgeBases + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: KnowledgeBases + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn list_knowledge_bases(&self) -> ListKnowledgeBases
pub fn list_knowledge_bases(&self) -> ListKnowledgeBases
Returns the list of all knowledge bases of the specified agent.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &KnowledgeBases, parent: &str
) -> Result<()> {
let mut list = client.list_knowledge_bases()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_knowledge_base(&self) -> GetKnowledgeBase
pub fn get_knowledge_base(&self) -> GetKnowledgeBase
Retrieves the specified knowledge base.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &KnowledgeBases, name: &str
) -> Result<()> {
let response = client.get_knowledge_base()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_knowledge_base(&self) -> CreateKnowledgeBase
pub fn create_knowledge_base(&self) -> CreateKnowledgeBase
Creates a knowledge base.
Example
use google_cloud_dialogflow_v2::model::KnowledgeBase;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &KnowledgeBases, parent: &str
) -> Result<()> {
let response = client.create_knowledge_base()
.set_parent(parent)
.set_knowledge_base(
KnowledgeBase::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_knowledge_base(&self) -> DeleteKnowledgeBase
pub fn delete_knowledge_base(&self) -> DeleteKnowledgeBase
Deletes the specified knowledge base.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &KnowledgeBases, name: &str
) -> Result<()> {
client.delete_knowledge_base()
.set_name(name)
.send().await?;
Ok(())
}Sourcepub fn update_knowledge_base(&self) -> UpdateKnowledgeBase
pub fn update_knowledge_base(&self) -> UpdateKnowledgeBase
Updates the specified knowledge base.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_dialogflow_v2::model::KnowledgeBase;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &KnowledgeBases, name: &str
) -> Result<()> {
let response = client.update_knowledge_base()
.set_knowledge_base(
KnowledgeBase::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &KnowledgeBases
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &KnowledgeBases
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &KnowledgeBases
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &KnowledgeBases
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &KnowledgeBases
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for KnowledgeBases
impl Clone for KnowledgeBases
Sourcefn clone(&self) -> KnowledgeBases
fn clone(&self) -> KnowledgeBases
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more