pub struct SessionEntityTypes { /* private fields */ }session-entity-types only.Expand description
Implements a client for the Dialogflow API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
async fn sample(
project_id: &str,
session_id: &str,
) -> anyhow::Result<()> {
let client = SessionEntityTypes::builder().build().await?;
let mut list = client.list_session_entity_types()
.set_parent(format!("projects/{project_id}/agent/sessions/{session_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Service Description
Service for managing SessionEntityTypes.
Configuration
To configure SessionEntityTypes use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://dialogflow.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
SessionEntityTypes holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap SessionEntityTypes in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl SessionEntityTypes
impl SessionEntityTypes
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for SessionEntityTypes.
let client = SessionEntityTypes::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: SessionEntityTypes + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: SessionEntityTypes + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn list_session_entity_types(&self) -> ListSessionEntityTypes
pub fn list_session_entity_types(&self) -> ListSessionEntityTypes
Returns the list of all session entity types in the specified session.
This method doesn’t work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &SessionEntityTypes, project_id: &str, session_id: &str
) -> Result<()> {
let mut list = client.list_session_entity_types()
.set_parent(format!("projects/{project_id}/agent/sessions/{session_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_session_entity_type(&self) -> GetSessionEntityType
pub fn get_session_entity_type(&self) -> GetSessionEntityType
Retrieves the specified session entity type.
This method doesn’t work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &SessionEntityTypes, project_id: &str, session_id: &str, entity_type_id: &str
) -> Result<()> {
let response = client.get_session_entity_type()
.set_name(format!("projects/{project_id}/agent/sessions/{session_id}/entityTypes/{entity_type_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_session_entity_type(&self) -> CreateSessionEntityType
pub fn create_session_entity_type(&self) -> CreateSessionEntityType
Creates a session entity type.
If the specified session entity type already exists, overrides the session entity type.
This method doesn’t work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.
Example
use google_cloud_dialogflow_v2::model::SessionEntityType;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &SessionEntityTypes, project_id: &str, session_id: &str
) -> Result<()> {
let response = client.create_session_entity_type()
.set_parent(format!("projects/{project_id}/agent/sessions/{session_id}"))
.set_session_entity_type(
SessionEntityType::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_session_entity_type(&self) -> UpdateSessionEntityType
pub fn update_session_entity_type(&self) -> UpdateSessionEntityType
Updates the specified session entity type.
This method doesn’t work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_dialogflow_v2::model::SessionEntityType;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &SessionEntityTypes, project_id: &str, session_id: &str, entity_type_id: &str
) -> Result<()> {
let response = client.update_session_entity_type()
.set_session_entity_type(
SessionEntityType::new().set_name(format!("projects/{project_id}/agent/sessions/{session_id}/entityTypes/{entity_type_id}"))/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_session_entity_type(&self) -> DeleteSessionEntityType
pub fn delete_session_entity_type(&self) -> DeleteSessionEntityType
Deletes the specified session entity type.
This method doesn’t work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &SessionEntityTypes, project_id: &str, session_id: &str, entity_type_id: &str
) -> Result<()> {
client.delete_session_entity_type()
.set_name(format!("projects/{project_id}/agent/sessions/{session_id}/entityTypes/{entity_type_id}"))
.send().await?;
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
This method lists locations based on the resource scope provided in the [ListLocationsRequest.name] field:
- Global locations: If
nameis empty, the method lists the public locations available to all projects. * Project-specific locations: Ifnamefollows the formatprojects/{project}, the method lists locations visible to that specific project. This includes public, private, or other project-specific locations enabled for the project.
For gRPC and client library implementations, the resource name is
passed as the name field. For direct service calls, the resource
name is
incorporated into the request path based on the specific service
implementation and version.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &SessionEntityTypes
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &SessionEntityTypes
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &SessionEntityTypes
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &SessionEntityTypes
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_dialogflow_v2::Result;
async fn sample(
client: &SessionEntityTypes
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for SessionEntityTypes
impl Clone for SessionEntityTypes
Sourcefn clone(&self) -> SessionEntityTypes
fn clone(&self) -> SessionEntityTypes
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more