#[non_exhaustive]pub enum TelephonyDtmf {
Show 18 variants
Unspecified,
DtmfOne,
DtmfTwo,
DtmfThree,
DtmfFour,
DtmfFive,
DtmfSix,
DtmfSeven,
DtmfEight,
DtmfNine,
DtmfZero,
DtmfA,
DtmfB,
DtmfC,
DtmfD,
DtmfStar,
DtmfPound,
UnknownValue(UnknownValue),
}participants only.Expand description
DTMF digit in Telephony Gateway.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Not specified. This value may be used to indicate an absent digit.
DtmfOne
Number: ‘1’.
DtmfTwo
Number: ‘2’.
DtmfThree
Number: ‘3’.
DtmfFour
Number: ‘4’.
DtmfFive
Number: ‘5’.
DtmfSix
Number: ‘6’.
DtmfSeven
Number: ‘7’.
DtmfEight
Number: ‘8’.
DtmfNine
Number: ‘9’.
DtmfZero
Number: ‘0’.
DtmfA
Letter: ‘A’.
DtmfB
Letter: ‘B’.
DtmfC
Letter: ‘C’.
DtmfD
Letter: ‘D’.
DtmfStar
Asterisk/star: ‘*’.
DtmfPound
Pound/diamond/hash/square/gate/octothorpe: ‘#’.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using TelephonyDtmf::value or TelephonyDtmf::name.
Implementations