pub enum State {
Unspecified,
Stopped,
Loading,
Running,
UnknownValue(UnknownValue),
}
Available on crate feature environments only.
Represents an environment state. When an environment is pointed to a new
agent version, the environment is temporarily set to the LOADING state.
During that time, the environment keeps on serving the previous version of
the agent. After the new agent version is done loading, the environment is
set back to the RUNNING state.
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
New values appearing in future releases of the client library, and
New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some
guidelines.
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.