#[non_exhaustive]pub enum AgentDesktopSource {
Unspecified,
LivePerson,
GenesysCloud,
Twilio,
Salesforce,
Other,
UnknownValue(UnknownValue),
}conversation-profiles or conversations or participants only.Expand description
Enumeration of the Agent Desktop Source when using prebuilt Agent Assist integration modules.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Agent Desktop Source is not specified.
LivePerson
Agent Desktop Source is Live Person.
GenesysCloud
Agent Desktop Source is Genesys Cloud.
Twilio
Agent Desktop Source is Twilio.
Salesforce
Agent Desktop Source is Salesforce.
Other
UI Modules are in use but the desktop is either not currently released or setting this field to the applicable desktop.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using AgentDesktopSource::value or AgentDesktopSource::name.
Implementations