#[non_exhaustive]pub struct AgentAssistantFeedback {
pub answer_relevance: AnswerRelevance,
pub document_correctness: DocumentCorrectness,
pub document_efficiency: DocumentEfficiency,
pub summarization_feedback: Option<SummarizationFeedback>,
pub knowledge_search_feedback: Option<KnowledgeSearchFeedback>,
pub knowledge_assist_feedback: Option<KnowledgeAssistFeedback>,
/* private fields */
}answer-records only.Expand description
Detail feedback of Agent Assist result.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.answer_relevance: AnswerRelevanceOptional. Whether or not the suggested answer is relevant.
For example:
- Query: “Can I change my mailing address?”
- Suggested document says: “Items must be returned/exchanged within 60 days of the purchase date.”
- answer_relevance: AnswerRelevance.IRRELEVANT
document_correctness: DocumentCorrectnessOptional. Whether or not the information in the document is correct.
For example:
- Query: “Can I return the package in 2 days once received?”
- Suggested document says: “Items must be returned/exchanged within 60 days of the purchase date.”
- Ground truth: “No return or exchange is allowed.”
- document_correctness: INCORRECT
document_efficiency: DocumentEfficiencyOptional. Whether or not the suggested document is efficient. For example, if the document is poorly written, hard to understand, hard to use or too long to find useful information, document_efficiency is DocumentEfficiency.INEFFICIENT.
summarization_feedback: Option<SummarizationFeedback>Optional. Feedback for conversation summarization.
knowledge_search_feedback: Option<KnowledgeSearchFeedback>Optional. Feedback for knowledge search.
knowledge_assist_feedback: Option<KnowledgeAssistFeedback>Optional. Feedback for knowledge assist.
Implementations
Sourceimpl AgentAssistantFeedback
impl AgentAssistantFeedback
Sourcepub fn set_answer_relevance<T: Into<AnswerRelevance>>(self, v: T) -> Self
pub fn set_answer_relevance<T: Into<AnswerRelevance>>(self, v: T) -> Self
Sets the value of answer_relevance.
Example
use google_cloud_dialogflow_v2::model::agent_assistant_feedback::AnswerRelevance;
let x0 = AgentAssistantFeedback::new().set_answer_relevance(AnswerRelevance::Irrelevant);
let x1 = AgentAssistantFeedback::new().set_answer_relevance(AnswerRelevance::Relevant);Sourcepub fn set_document_correctness<T: Into<DocumentCorrectness>>(
self,
v: T,
) -> Self
pub fn set_document_correctness<T: Into<DocumentCorrectness>>( self, v: T, ) -> Self
Sets the value of document_correctness.
Example
use google_cloud_dialogflow_v2::model::agent_assistant_feedback::DocumentCorrectness;
let x0 = AgentAssistantFeedback::new().set_document_correctness(DocumentCorrectness::Incorrect);
let x1 = AgentAssistantFeedback::new().set_document_correctness(DocumentCorrectness::Correct);Sourcepub fn set_document_efficiency<T: Into<DocumentEfficiency>>(self, v: T) -> Self
pub fn set_document_efficiency<T: Into<DocumentEfficiency>>(self, v: T) -> Self
Sets the value of document_efficiency.
Example
use google_cloud_dialogflow_v2::model::agent_assistant_feedback::DocumentEfficiency;
let x0 = AgentAssistantFeedback::new().set_document_efficiency(DocumentEfficiency::Inefficient);
let x1 = AgentAssistantFeedback::new().set_document_efficiency(DocumentEfficiency::Efficient);Sourcepub fn set_summarization_feedback<T>(self, v: T) -> Selfwhere
T: Into<SummarizationFeedback>,
pub fn set_summarization_feedback<T>(self, v: T) -> Selfwhere
T: Into<SummarizationFeedback>,
Sets the value of summarization_feedback.
Example
use google_cloud_dialogflow_v2::model::agent_assistant_feedback::SummarizationFeedback;
let x = AgentAssistantFeedback::new().set_summarization_feedback(SummarizationFeedback::default()/* use setters */);Sourcepub fn set_or_clear_summarization_feedback<T>(self, v: Option<T>) -> Selfwhere
T: Into<SummarizationFeedback>,
pub fn set_or_clear_summarization_feedback<T>(self, v: Option<T>) -> Selfwhere
T: Into<SummarizationFeedback>,
Sets or clears the value of summarization_feedback.
Example
use google_cloud_dialogflow_v2::model::agent_assistant_feedback::SummarizationFeedback;
let x = AgentAssistantFeedback::new().set_or_clear_summarization_feedback(Some(SummarizationFeedback::default()/* use setters */));
let x = AgentAssistantFeedback::new().set_or_clear_summarization_feedback(None::<SummarizationFeedback>);Sourcepub fn set_knowledge_search_feedback<T>(self, v: T) -> Selfwhere
T: Into<KnowledgeSearchFeedback>,
pub fn set_knowledge_search_feedback<T>(self, v: T) -> Selfwhere
T: Into<KnowledgeSearchFeedback>,
Sets the value of knowledge_search_feedback.
Example
use google_cloud_dialogflow_v2::model::agent_assistant_feedback::KnowledgeSearchFeedback;
let x = AgentAssistantFeedback::new().set_knowledge_search_feedback(KnowledgeSearchFeedback::default()/* use setters */);Sourcepub fn set_or_clear_knowledge_search_feedback<T>(self, v: Option<T>) -> Selfwhere
T: Into<KnowledgeSearchFeedback>,
pub fn set_or_clear_knowledge_search_feedback<T>(self, v: Option<T>) -> Selfwhere
T: Into<KnowledgeSearchFeedback>,
Sets or clears the value of knowledge_search_feedback.
Example
use google_cloud_dialogflow_v2::model::agent_assistant_feedback::KnowledgeSearchFeedback;
let x = AgentAssistantFeedback::new().set_or_clear_knowledge_search_feedback(Some(KnowledgeSearchFeedback::default()/* use setters */));
let x = AgentAssistantFeedback::new().set_or_clear_knowledge_search_feedback(None::<KnowledgeSearchFeedback>);Sourcepub fn set_knowledge_assist_feedback<T>(self, v: T) -> Selfwhere
T: Into<KnowledgeAssistFeedback>,
pub fn set_knowledge_assist_feedback<T>(self, v: T) -> Selfwhere
T: Into<KnowledgeAssistFeedback>,
Sets the value of knowledge_assist_feedback.
Example
use google_cloud_dialogflow_v2::model::agent_assistant_feedback::KnowledgeAssistFeedback;
let x = AgentAssistantFeedback::new().set_knowledge_assist_feedback(KnowledgeAssistFeedback::default()/* use setters */);Sourcepub fn set_or_clear_knowledge_assist_feedback<T>(self, v: Option<T>) -> Selfwhere
T: Into<KnowledgeAssistFeedback>,
pub fn set_or_clear_knowledge_assist_feedback<T>(self, v: Option<T>) -> Selfwhere
T: Into<KnowledgeAssistFeedback>,
Sets or clears the value of knowledge_assist_feedback.
Example
use google_cloud_dialogflow_v2::model::agent_assistant_feedback::KnowledgeAssistFeedback;
let x = AgentAssistantFeedback::new().set_or_clear_knowledge_assist_feedback(Some(KnowledgeAssistFeedback::default()/* use setters */));
let x = AgentAssistantFeedback::new().set_or_clear_knowledge_assist_feedback(None::<KnowledgeAssistFeedback>);Trait Implementations
Sourceimpl Clone for AgentAssistantFeedback
impl Clone for AgentAssistantFeedback
Sourcefn clone(&self) -> AgentAssistantFeedback
fn clone(&self) -> AgentAssistantFeedback
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for AgentAssistantFeedback
impl Debug for AgentAssistantFeedback
Sourceimpl Default for AgentAssistantFeedback
impl Default for AgentAssistantFeedback
Sourcefn default() -> AgentAssistantFeedback
fn default() -> AgentAssistantFeedback
Sourceimpl Message for AgentAssistantFeedback
impl Message for AgentAssistantFeedback
Sourceimpl PartialEq for AgentAssistantFeedback
impl PartialEq for AgentAssistantFeedback
impl StructuralPartialEq for AgentAssistantFeedback