#[non_exhaustive]pub struct AgentAssistantRecord {
pub answer: Option<Answer>,
/* private fields */
}answer-records only.Expand description
Represents a record of a human agent assist answer.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.answer: Option<Answer>Output only. The agent assist answer.
Implementations
Sourceimpl AgentAssistantRecord
impl AgentAssistantRecord
Sourcepub fn set_answer<T: Into<Option<Answer>>>(self, v: T) -> Self
pub fn set_answer<T: Into<Option<Answer>>>(self, v: T) -> Self
Sets the value of answer.
Note that all the setters affecting answer are mutually
exclusive.
Example
use google_cloud_dialogflow_v2::model::ArticleAnswer;
let x = AgentAssistantRecord::new().set_answer(Some(
google_cloud_dialogflow_v2::model::agent_assistant_record::Answer::ArticleSuggestionAnswer(ArticleAnswer::default().into())));Sourcepub fn article_suggestion_answer(&self) -> Option<&Box<ArticleAnswer>>
pub fn article_suggestion_answer(&self) -> Option<&Box<ArticleAnswer>>
The value of answer
if it holds a ArticleSuggestionAnswer, None if the field is not set or
holds a different branch.
Sourcepub fn set_article_suggestion_answer<T: Into<Box<ArticleAnswer>>>(
self,
v: T,
) -> Self
pub fn set_article_suggestion_answer<T: Into<Box<ArticleAnswer>>>( self, v: T, ) -> Self
Sets the value of answer
to hold a ArticleSuggestionAnswer.
Note that all the setters affecting answer are
mutually exclusive.
Example
use google_cloud_dialogflow_v2::model::ArticleAnswer;
let x = AgentAssistantRecord::new().set_article_suggestion_answer(ArticleAnswer::default()/* use setters */);
assert!(x.article_suggestion_answer().is_some());
assert!(x.faq_answer().is_none());
assert!(x.dialogflow_assist_answer().is_none());
assert!(x.generator_suggestion().is_none());Sourcepub fn faq_answer(&self) -> Option<&Box<FaqAnswer>>
pub fn faq_answer(&self) -> Option<&Box<FaqAnswer>>
The value of answer
if it holds a FaqAnswer, None if the field is not set or
holds a different branch.
Sourcepub fn set_faq_answer<T: Into<Box<FaqAnswer>>>(self, v: T) -> Self
pub fn set_faq_answer<T: Into<Box<FaqAnswer>>>(self, v: T) -> Self
Sets the value of answer
to hold a FaqAnswer.
Note that all the setters affecting answer are
mutually exclusive.
Example
use google_cloud_dialogflow_v2::model::FaqAnswer;
let x = AgentAssistantRecord::new().set_faq_answer(FaqAnswer::default()/* use setters */);
assert!(x.faq_answer().is_some());
assert!(x.article_suggestion_answer().is_none());
assert!(x.dialogflow_assist_answer().is_none());
assert!(x.generator_suggestion().is_none());Sourcepub fn dialogflow_assist_answer(&self) -> Option<&Box<DialogflowAssistAnswer>>
pub fn dialogflow_assist_answer(&self) -> Option<&Box<DialogflowAssistAnswer>>
The value of answer
if it holds a DialogflowAssistAnswer, None if the field is not set or
holds a different branch.
Sourcepub fn set_dialogflow_assist_answer<T: Into<Box<DialogflowAssistAnswer>>>(
self,
v: T,
) -> Self
pub fn set_dialogflow_assist_answer<T: Into<Box<DialogflowAssistAnswer>>>( self, v: T, ) -> Self
Sets the value of answer
to hold a DialogflowAssistAnswer.
Note that all the setters affecting answer are
mutually exclusive.
Example
use google_cloud_dialogflow_v2::model::DialogflowAssistAnswer;
let x = AgentAssistantRecord::new().set_dialogflow_assist_answer(DialogflowAssistAnswer::default()/* use setters */);
assert!(x.dialogflow_assist_answer().is_some());
assert!(x.article_suggestion_answer().is_none());
assert!(x.faq_answer().is_none());
assert!(x.generator_suggestion().is_none());Sourcepub fn generator_suggestion(&self) -> Option<&Box<GeneratorSuggestion>>
pub fn generator_suggestion(&self) -> Option<&Box<GeneratorSuggestion>>
The value of answer
if it holds a GeneratorSuggestion, None if the field is not set or
holds a different branch.
Sourcepub fn set_generator_suggestion<T: Into<Box<GeneratorSuggestion>>>(
self,
v: T,
) -> Self
pub fn set_generator_suggestion<T: Into<Box<GeneratorSuggestion>>>( self, v: T, ) -> Self
Sets the value of answer
to hold a GeneratorSuggestion.
Note that all the setters affecting answer are
mutually exclusive.
Example
use google_cloud_dialogflow_v2::model::GeneratorSuggestion;
let x = AgentAssistantRecord::new().set_generator_suggestion(GeneratorSuggestion::default()/* use setters */);
assert!(x.generator_suggestion().is_some());
assert!(x.article_suggestion_answer().is_none());
assert!(x.faq_answer().is_none());
assert!(x.dialogflow_assist_answer().is_none());Trait Implementations
Sourceimpl Clone for AgentAssistantRecord
impl Clone for AgentAssistantRecord
Sourcefn clone(&self) -> AgentAssistantRecord
fn clone(&self) -> AgentAssistantRecord
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for AgentAssistantRecord
impl Debug for AgentAssistantRecord
Sourceimpl Default for AgentAssistantRecord
impl Default for AgentAssistantRecord
Sourcefn default() -> AgentAssistantRecord
fn default() -> AgentAssistantRecord
Sourceimpl Message for AgentAssistantRecord
impl Message for AgentAssistantRecord
Sourceimpl PartialEq for AgentAssistantRecord
impl PartialEq for AgentAssistantRecord
impl StructuralPartialEq for AgentAssistantRecord