AgentCoachingInstruction

Struct AgentCoachingInstruction 

#[non_exhaustive]
pub struct AgentCoachingInstruction { pub display_name: String, pub display_details: String, pub condition: String, pub agent_action: String, pub system_action: String, pub duplicate_check_result: Option<DuplicateCheckResult>, pub triggering_event: TriggerEvent, /* private fields */ }
Available on crate features answer-records or conversations or generator-evaluations or generators or participants only.
Agent Coaching instructions that customer can configure.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
display_name: String

Optional. Display name for the instruction.

display_details: String

Optional. The detailed description of this instruction.

condition: String

Optional. The condition of the instruction. For example, “the customer wants to cancel an order”. If the users want the instruction to be triggered unconditionally, the condition can be empty.

agent_action: String

Optional. The action that human agent should take. For example, “apologize for the slow shipping”. If the users only want to use agent coaching for intent detection, agent_action can be empty

system_action: String

Optional. The action that system should take. For example, “call GetOrderTime with order_number={order number provided by the customer}”. If the users don’t have plugins or don’t want to trigger plugins, the system_action can be empty

duplicate_check_result: Option<DuplicateCheckResult>

Output only. Duplication check for the AgentCoachingInstruction.

triggering_event: TriggerEvent

Optional. The event that should trigger this instruction. If UNSPECIFIED, the instruction triggering will be same as the generator’s trigger_event.

Implementations

Source

impl AgentCoachingInstruction

pub fn new() -> Self

pub fn set_display_name<T: Into<String>>(self, v: T) -> Self

Sets the value of display_name.

Example
let x = AgentCoachingInstruction::new().set_display_name("example");
pub fn set_display_details<T: Into<String>>(self, v: T) -> Self

Sets the value of display_details.

Example
let x = AgentCoachingInstruction::new().set_display_details("example");
pub fn set_condition<T: Into<String>>(self, v: T) -> Self

Sets the value of condition.

Example
let x = AgentCoachingInstruction::new().set_condition("example");
pub fn set_agent_action<T: Into<String>>(self, v: T) -> Self

Sets the value of agent_action.

Example
let x = AgentCoachingInstruction::new().set_agent_action("example");
pub fn set_system_action<T: Into<String>>(self, v: T) -> Self

Sets the value of system_action.

Example
let x = AgentCoachingInstruction::new().set_system_action("example");
pub fn set_duplicate_check_result<T>(self, v: T) -> Self

Sets the value of duplicate_check_result.

Example
use google_cloud_dialogflow_v2::model::agent_coaching_instruction::DuplicateCheckResult;
let x = AgentCoachingInstruction::new().set_duplicate_check_result(DuplicateCheckResult::default()/* use setters */);
pub fn set_or_clear_duplicate_check_result<T>(self, v: Option<T>) -> Self

Sets or clears the value of duplicate_check_result.

Example
use google_cloud_dialogflow_v2::model::agent_coaching_instruction::DuplicateCheckResult;
let x = AgentCoachingInstruction::new().set_or_clear_duplicate_check_result(Some(DuplicateCheckResult::default()/* use setters */));
let x = AgentCoachingInstruction::new().set_or_clear_duplicate_check_result(None::<DuplicateCheckResult>);
pub fn set_triggering_event<T: Into<TriggerEvent>>(self, v: T) -> Self

Sets the value of triggering_event.

Example
use google_cloud_dialogflow_v2::model::agent_coaching_instruction::TriggerEvent;
let x0 = AgentCoachingInstruction::new().set_triggering_event(TriggerEvent::EndOfUtterance);
let x1 = AgentCoachingInstruction::new().set_triggering_event(TriggerEvent::ManualCall);
let x2 = AgentCoachingInstruction::new().set_triggering_event(TriggerEvent::CustomerMessage);