#[non_exhaustive]pub struct AnalyzeContentRequest {
pub participant: String,
pub reply_audio_config: Option<OutputAudioConfig>,
pub query_params: Option<QueryParameters>,
pub assist_query_params: Option<AssistQueryParameters>,
pub cx_parameters: Option<Struct>,
pub request_id: String,
pub input: Option<Input>,
/* private fields */
}participants only.Expand description
The request message for Participants.AnalyzeContent.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.participant: StringRequired. The name of the participant this text comes from.
Format: projects/<Project ID>/locations/<Location ID>/conversations/<Conversation ID>/participants/<Participant ID>.
reply_audio_config: Option<OutputAudioConfig>Speech synthesis configuration. The speech synthesis settings for a virtual agent that may be configured for the associated conversation profile are not used when calling AnalyzeContent. If this configuration is not supplied, speech synthesis is disabled.
query_params: Option<QueryParameters>Parameters for a Dialogflow virtual-agent query.
assist_query_params: Option<AssistQueryParameters>Parameters for a human assist query.
cx_parameters: Option<Struct>Additional parameters to be put into Dialogflow CX session parameters. To remove a parameter from the session, clients should explicitly set the parameter value to null.
Note: this field should only be used if you are connecting to a Dialogflow CX agent.
request_id: StringA unique identifier for this request. Restricted to 36 ASCII characters.
A random UUID is recommended.
This request is only idempotent if a request_id is provided.
input: Option<Input>Required. The input content.
Implementations
Sourceimpl AnalyzeContentRequest
impl AnalyzeContentRequest
Sourcepub fn set_participant<T: Into<String>>(self, v: T) -> Self
pub fn set_participant<T: Into<String>>(self, v: T) -> Self
Sets the value of participant.
Example
let x = AnalyzeContentRequest::new().set_participant(format!("projects/{project_id}/conversations/{conversation_id}/participants/{participant_id}"));Sourcepub fn set_reply_audio_config<T>(self, v: T) -> Selfwhere
T: Into<OutputAudioConfig>,
pub fn set_reply_audio_config<T>(self, v: T) -> Selfwhere
T: Into<OutputAudioConfig>,
Sets the value of reply_audio_config.
Example
use google_cloud_dialogflow_v2::model::OutputAudioConfig;
let x = AnalyzeContentRequest::new().set_reply_audio_config(OutputAudioConfig::default()/* use setters */);Sourcepub fn set_or_clear_reply_audio_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<OutputAudioConfig>,
pub fn set_or_clear_reply_audio_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<OutputAudioConfig>,
Sets or clears the value of reply_audio_config.
Example
use google_cloud_dialogflow_v2::model::OutputAudioConfig;
let x = AnalyzeContentRequest::new().set_or_clear_reply_audio_config(Some(OutputAudioConfig::default()/* use setters */));
let x = AnalyzeContentRequest::new().set_or_clear_reply_audio_config(None::<OutputAudioConfig>);Sourcepub fn set_query_params<T>(self, v: T) -> Selfwhere
T: Into<QueryParameters>,
pub fn set_query_params<T>(self, v: T) -> Selfwhere
T: Into<QueryParameters>,
Sets the value of query_params.
Example
use google_cloud_dialogflow_v2::model::QueryParameters;
let x = AnalyzeContentRequest::new().set_query_params(QueryParameters::default()/* use setters */);Sourcepub fn set_or_clear_query_params<T>(self, v: Option<T>) -> Selfwhere
T: Into<QueryParameters>,
pub fn set_or_clear_query_params<T>(self, v: Option<T>) -> Selfwhere
T: Into<QueryParameters>,
Sets or clears the value of query_params.
Example
use google_cloud_dialogflow_v2::model::QueryParameters;
let x = AnalyzeContentRequest::new().set_or_clear_query_params(Some(QueryParameters::default()/* use setters */));
let x = AnalyzeContentRequest::new().set_or_clear_query_params(None::<QueryParameters>);Sourcepub fn set_assist_query_params<T>(self, v: T) -> Selfwhere
T: Into<AssistQueryParameters>,
pub fn set_assist_query_params<T>(self, v: T) -> Selfwhere
T: Into<AssistQueryParameters>,
Sets the value of assist_query_params.
Example
use google_cloud_dialogflow_v2::model::AssistQueryParameters;
let x = AnalyzeContentRequest::new().set_assist_query_params(AssistQueryParameters::default()/* use setters */);Sourcepub fn set_or_clear_assist_query_params<T>(self, v: Option<T>) -> Selfwhere
T: Into<AssistQueryParameters>,
pub fn set_or_clear_assist_query_params<T>(self, v: Option<T>) -> Selfwhere
T: Into<AssistQueryParameters>,
Sets or clears the value of assist_query_params.
Example
use google_cloud_dialogflow_v2::model::AssistQueryParameters;
let x = AnalyzeContentRequest::new().set_or_clear_assist_query_params(Some(AssistQueryParameters::default()/* use setters */));
let x = AnalyzeContentRequest::new().set_or_clear_assist_query_params(None::<AssistQueryParameters>);Sourcepub fn set_cx_parameters<T>(self, v: T) -> Self
pub fn set_cx_parameters<T>(self, v: T) -> Self
Sets the value of cx_parameters.
Example
use wkt::Struct;
let x = AnalyzeContentRequest::new().set_cx_parameters(Struct::default()/* use setters */);Sourcepub fn set_or_clear_cx_parameters<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_cx_parameters<T>(self, v: Option<T>) -> Self
Sets or clears the value of cx_parameters.
Example
use wkt::Struct;
let x = AnalyzeContentRequest::new().set_or_clear_cx_parameters(Some(Struct::default()/* use setters */));
let x = AnalyzeContentRequest::new().set_or_clear_cx_parameters(None::<Struct>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = AnalyzeContentRequest::new().set_request_id("example");Sourcepub fn set_input<T: Into<Option<Input>>>(self, v: T) -> Self
pub fn set_input<T: Into<Option<Input>>>(self, v: T) -> Self
Sets the value of input.
Note that all the setters affecting input are mutually
exclusive.
Example
use google_cloud_dialogflow_v2::model::TextInput;
let x = AnalyzeContentRequest::new().set_input(Some(
google_cloud_dialogflow_v2::model::analyze_content_request::Input::TextInput(TextInput::default().into())));Sourcepub fn text_input(&self) -> Option<&Box<TextInput>>
pub fn text_input(&self) -> Option<&Box<TextInput>>
The value of input
if it holds a TextInput, None if the field is not set or
holds a different branch.
Sourcepub fn set_text_input<T: Into<Box<TextInput>>>(self, v: T) -> Self
pub fn set_text_input<T: Into<Box<TextInput>>>(self, v: T) -> Self
Sets the value of input
to hold a TextInput.
Note that all the setters affecting input are
mutually exclusive.
Example
use google_cloud_dialogflow_v2::model::TextInput;
let x = AnalyzeContentRequest::new().set_text_input(TextInput::default()/* use setters */);
assert!(x.text_input().is_some());
assert!(x.audio_input().is_none());
assert!(x.event_input().is_none());
assert!(x.suggestion_input().is_none());Sourcepub fn audio_input(&self) -> Option<&Box<AudioInput>>
pub fn audio_input(&self) -> Option<&Box<AudioInput>>
The value of input
if it holds a AudioInput, None if the field is not set or
holds a different branch.
Sourcepub fn set_audio_input<T: Into<Box<AudioInput>>>(self, v: T) -> Self
pub fn set_audio_input<T: Into<Box<AudioInput>>>(self, v: T) -> Self
Sets the value of input
to hold a AudioInput.
Note that all the setters affecting input are
mutually exclusive.
Example
use google_cloud_dialogflow_v2::model::AudioInput;
let x = AnalyzeContentRequest::new().set_audio_input(AudioInput::default()/* use setters */);
assert!(x.audio_input().is_some());
assert!(x.text_input().is_none());
assert!(x.event_input().is_none());
assert!(x.suggestion_input().is_none());Sourcepub fn event_input(&self) -> Option<&Box<EventInput>>
pub fn event_input(&self) -> Option<&Box<EventInput>>
The value of input
if it holds a EventInput, None if the field is not set or
holds a different branch.
Sourcepub fn set_event_input<T: Into<Box<EventInput>>>(self, v: T) -> Self
pub fn set_event_input<T: Into<Box<EventInput>>>(self, v: T) -> Self
Sets the value of input
to hold a EventInput.
Note that all the setters affecting input are
mutually exclusive.
Example
use google_cloud_dialogflow_v2::model::EventInput;
let x = AnalyzeContentRequest::new().set_event_input(EventInput::default()/* use setters */);
assert!(x.event_input().is_some());
assert!(x.text_input().is_none());
assert!(x.audio_input().is_none());
assert!(x.suggestion_input().is_none());Sourcepub fn suggestion_input(&self) -> Option<&Box<SuggestionInput>>
pub fn suggestion_input(&self) -> Option<&Box<SuggestionInput>>
The value of input
if it holds a SuggestionInput, None if the field is not set or
holds a different branch.
Sourcepub fn set_suggestion_input<T: Into<Box<SuggestionInput>>>(self, v: T) -> Self
pub fn set_suggestion_input<T: Into<Box<SuggestionInput>>>(self, v: T) -> Self
Sets the value of input
to hold a SuggestionInput.
Note that all the setters affecting input are
mutually exclusive.
Example
use google_cloud_dialogflow_v2::model::SuggestionInput;
let x = AnalyzeContentRequest::new().set_suggestion_input(SuggestionInput::default()/* use setters */);
assert!(x.suggestion_input().is_some());
assert!(x.text_input().is_none());
assert!(x.audio_input().is_none());
assert!(x.event_input().is_none());Trait Implementations
Sourceimpl Clone for AnalyzeContentRequest
impl Clone for AnalyzeContentRequest
Sourcefn clone(&self) -> AnalyzeContentRequest
fn clone(&self) -> AnalyzeContentRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for AnalyzeContentRequest
impl Debug for AnalyzeContentRequest
Sourceimpl Default for AnalyzeContentRequest
impl Default for AnalyzeContentRequest
Sourcefn default() -> AnalyzeContentRequest
fn default() -> AnalyzeContentRequest
Sourceimpl Message for AnalyzeContentRequest
impl Message for AnalyzeContentRequest
Sourceimpl PartialEq for AnalyzeContentRequest
impl PartialEq for AnalyzeContentRequest
impl StructuralPartialEq for AnalyzeContentRequest