AnalyzeContentResponse

Struct AnalyzeContentResponse 

#[non_exhaustive]
pub struct AnalyzeContentResponse { pub reply_text: String, pub reply_audio: Option<OutputAudio>, pub automated_agent_reply: Option<AutomatedAgentReply>, pub message: Option<Message>, pub human_agent_suggestion_results: Vec<SuggestionResult>, pub end_user_suggestion_results: Vec<SuggestionResult>, pub dtmf_parameters: Option<DtmfParameters>, /* private fields */ }
Available on crate feature participants only.
The response message for Participants.AnalyzeContent.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
reply_text: String

The output text content. This field is set if the automated agent responded with text to show to the user.

reply_audio: Option<OutputAudio>

The audio data bytes encoded as specified in the request. This field is set if:

  • reply_audio_config was specified in the request, or
  • The automated agent responded with audio to play to the user. In such case, reply_audio.config contains settings used to synthesize the speech.

In some scenarios, multiple output audio fields may be present in the response structure. In these cases, only the top-most-level audio output has content.

automated_agent_reply: Option<AutomatedAgentReply>

Only set if a Dialogflow automated agent has responded. Note that in [AutomatedAgentReply.DetectIntentResponse][], [Sessions.DetectIntentResponse.output_audio][] and [Sessions.DetectIntentResponse.output_audio_config][] are always empty, use reply_audio instead.

message: Option<Message>

Message analyzed by CCAI.

human_agent_suggestion_results: Vec<SuggestionResult>

The suggestions for most recent human agent. The order is the same as HumanAgentAssistantConfig.SuggestionConfig.feature_configs of HumanAgentAssistantConfig.human_agent_suggestion_config.

Note that any failure of Agent Assist features will not lead to the overall failure of an AnalyzeContent API call. Instead, the features will fail silently with the error field set in the corresponding SuggestionResult.

end_user_suggestion_results: Vec<SuggestionResult>

The suggestions for end user. The order is the same as HumanAgentAssistantConfig.SuggestionConfig.feature_configs of HumanAgentAssistantConfig.end_user_suggestion_config.

Same as human_agent_suggestion_results, any failure of Agent Assist features will not lead to the overall failure of an AnalyzeContent API call. Instead, the features will fail silently with the error field set in the corresponding SuggestionResult.

dtmf_parameters: Option<DtmfParameters>

Indicates the parameters of DTMF.

Implementations

Source

impl AnalyzeContentResponse

pub fn new() -> Self

pub fn set_reply_text<T: Into<String>>(self, v: T) -> Self

Sets the value of reply_text.

Example
let x = AnalyzeContentResponse::new().set_reply_text("example");
pub fn set_reply_audio<T>(self, v: T) -> Self
where T: Into<OutputAudio>,

Sets the value of reply_audio.

Example
use google_cloud_dialogflow_v2::model::OutputAudio;
let x = AnalyzeContentResponse::new().set_reply_audio(OutputAudio::default()/* use setters */);
pub fn set_or_clear_reply_audio<T>(self, v: Option<T>) -> Self
where T: Into<OutputAudio>,

Sets or clears the value of reply_audio.

Example
use google_cloud_dialogflow_v2::model::OutputAudio;
let x = AnalyzeContentResponse::new().set_or_clear_reply_audio(Some(OutputAudio::default()/* use setters */));
let x = AnalyzeContentResponse::new().set_or_clear_reply_audio(None::<OutputAudio>);
pub fn set_automated_agent_reply<T>(self, v: T) -> Self

Sets the value of automated_agent_reply.

Example
use google_cloud_dialogflow_v2::model::AutomatedAgentReply;
let x = AnalyzeContentResponse::new().set_automated_agent_reply(AutomatedAgentReply::default()/* use setters */);
pub fn set_or_clear_automated_agent_reply<T>(self, v: Option<T>) -> Self

Sets or clears the value of automated_agent_reply.

Example
use google_cloud_dialogflow_v2::model::AutomatedAgentReply;
let x = AnalyzeContentResponse::new().set_or_clear_automated_agent_reply(Some(AutomatedAgentReply::default()/* use setters */));
let x = AnalyzeContentResponse::new().set_or_clear_automated_agent_reply(None::<AutomatedAgentReply>);
pub fn set_message<T>(self, v: T) -> Self
where T: Into<Message>,

Sets the value of message.

Example
use google_cloud_dialogflow_v2::model::Message;
let x = AnalyzeContentResponse::new().set_message(Message::default()/* use setters */);
pub fn set_or_clear_message<T>(self, v: Option<T>) -> Self
where T: Into<Message>,

Sets or clears the value of message.

Example
use google_cloud_dialogflow_v2::model::Message;
let x = AnalyzeContentResponse::new().set_or_clear_message(Some(Message::default()/* use setters */));
let x = AnalyzeContentResponse::new().set_or_clear_message(None::<Message>);
pub fn set_human_agent_suggestion_results<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<SuggestionResult>,

Sets the value of human_agent_suggestion_results.

Example
use google_cloud_dialogflow_v2::model::SuggestionResult;
let x = AnalyzeContentResponse::new()
    .set_human_agent_suggestion_results([
        SuggestionResult::default()/* use setters */,
        SuggestionResult::default()/* use (different) setters */,
    ]);
pub fn set_end_user_suggestion_results<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<SuggestionResult>,

Sets the value of end_user_suggestion_results.

Example
use google_cloud_dialogflow_v2::model::SuggestionResult;
let x = AnalyzeContentResponse::new()
    .set_end_user_suggestion_results([
        SuggestionResult::default()/* use setters */,
        SuggestionResult::default()/* use (different) setters */,
    ]);
pub fn set_dtmf_parameters<T>(self, v: T) -> Self
where T: Into<DtmfParameters>,

Sets the value of dtmf_parameters.

Example
use google_cloud_dialogflow_v2::model::DtmfParameters;
let x = AnalyzeContentResponse::new().set_dtmf_parameters(DtmfParameters::default()/* use setters */);
pub fn set_or_clear_dtmf_parameters<T>(self, v: Option<T>) -> Self
where T: Into<DtmfParameters>,

Sets or clears the value of dtmf_parameters.

Example
use google_cloud_dialogflow_v2::model::DtmfParameters;
let x = AnalyzeContentResponse::new().set_or_clear_dtmf_parameters(Some(DtmfParameters::default()/* use setters */));
let x = AnalyzeContentResponse::new().set_or_clear_dtmf_parameters(None::<DtmfParameters>);