#[non_exhaustive]pub struct CesAppSpec {
pub ces_app: String,
pub confirmation_requirement: ConfirmationRequirement,
pub proactive_enabled: Option<bool>,
pub reactive_enabled: Option<bool>,
/* private fields */
}conversations or generator-evaluations or generators only.Expand description
Spec of CES app that the generator can choose from.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ces_app: StringOptional. Format: projects/<Project ID>/locations/<Location ID>/apps/<app ID>.
confirmation_requirement: ConfirmationRequirementOptional. Indicates whether the app requires human confirmation.
proactive_enabled: Option<bool>Optional. Only applicable for CompanionAgent.
Indicates whether the ces app is enabled in proactive mode.
At least one of proactive_enabled or reactive_enabled should be
true; otherwise, the ces app will be ignored.
reactive_enabled: Option<bool>Optional. Only applicable for CompanionAgent.
Indicates whether the ces app is enabled in reactive mode.
At least one of proactive_enabled or reactive_enabled should be
true; otherwise, the ces app will be ignored.
Implementations
Sourceimpl CesAppSpec
impl CesAppSpec
Sourcepub fn set_ces_app<T: Into<String>>(self, v: T) -> Self
pub fn set_ces_app<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_confirmation_requirement<T: Into<ConfirmationRequirement>>(
self,
v: T,
) -> Self
pub fn set_confirmation_requirement<T: Into<ConfirmationRequirement>>( self, v: T, ) -> Self
Sets the value of confirmation_requirement.
Example
use google_cloud_dialogflow_v2::model::tool::ConfirmationRequirement;
let x0 = CesAppSpec::new().set_confirmation_requirement(ConfirmationRequirement::Required);
let x1 = CesAppSpec::new().set_confirmation_requirement(ConfirmationRequirement::NotRequired);Sourcepub fn set_proactive_enabled<T>(self, v: T) -> Self
pub fn set_proactive_enabled<T>(self, v: T) -> Self
Sets the value of proactive_enabled.
Example
let x = CesAppSpec::new().set_proactive_enabled(true);Sourcepub fn set_or_clear_proactive_enabled<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_proactive_enabled<T>(self, v: Option<T>) -> Self
Sets or clears the value of proactive_enabled.
Example
let x = CesAppSpec::new().set_or_clear_proactive_enabled(Some(false));
let x = CesAppSpec::new().set_or_clear_proactive_enabled(None::<bool>);Sourcepub fn set_reactive_enabled<T>(self, v: T) -> Self
pub fn set_reactive_enabled<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_reactive_enabled<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_reactive_enabled<T>(self, v: Option<T>) -> Self
Sets or clears the value of reactive_enabled.
Example
let x = CesAppSpec::new().set_or_clear_reactive_enabled(Some(false));
let x = CesAppSpec::new().set_or_clear_reactive_enabled(None::<bool>);Trait Implementations
Sourceimpl Clone for CesAppSpec
impl Clone for CesAppSpec
Sourcefn clone(&self) -> CesAppSpec
fn clone(&self) -> CesAppSpec
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CesAppSpec
impl Debug for CesAppSpec
Sourceimpl Default for CesAppSpec
impl Default for CesAppSpec
Sourcefn default() -> CesAppSpec
fn default() -> CesAppSpec
Sourceimpl PartialEq for CesAppSpec
impl PartialEq for CesAppSpec
impl StructuralPartialEq for CesAppSpec