#[non_exhaustive]pub struct ConversationDataset {
pub name: String,
pub display_name: String,
pub description: String,
pub create_time: Option<Timestamp>,
pub input_config: Option<InputConfig>,
pub conversation_info: Option<ConversationInfo>,
pub conversation_count: i64,
pub satisfies_pzi: Option<bool>,
pub satisfies_pzs: Option<bool>,
/* private fields */
}conversation-datasets only.Expand description
Represents a conversation dataset that a user imports raw data into. The data inside ConversationDataset can not be changed after ImportConversationData finishes (and calling ImportConversationData on a dataset that already has data is not allowed).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. ConversationDataset resource name. Format:
projects/<Project ID>/locations/<Location ID>/conversationDatasets/<Conversation Dataset ID>
display_name: StringRequired. The display name of the dataset. Maximum of 64 bytes.
description: StringOptional. The description of the dataset. Maximum of 10000 bytes.
create_time: Option<Timestamp>Output only. Creation time of this dataset.
input_config: Option<InputConfig>Output only. Input configurations set during conversation data import.
conversation_info: Option<ConversationInfo>Output only. Metadata set during conversation data import.
conversation_count: i64Output only. The number of conversations this conversation dataset contains.
satisfies_pzi: Option<bool>Output only. A read only boolean field reflecting Zone Isolation status of the dataset.
satisfies_pzs: Option<bool>Output only. A read only boolean field reflecting Zone Separation status of the dataset.
Implementations
Sourceimpl ConversationDataset
impl ConversationDataset
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
let x = ConversationDataset::new().set_display_name("example");Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sets the value of description.
Example
let x = ConversationDataset::new().set_description("example");Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = ConversationDataset::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = ConversationDataset::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = ConversationDataset::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_input_config<T>(self, v: T) -> Selfwhere
T: Into<InputConfig>,
pub fn set_input_config<T>(self, v: T) -> Selfwhere
T: Into<InputConfig>,
Sets the value of input_config.
Example
use google_cloud_dialogflow_v2::model::InputConfig;
let x = ConversationDataset::new().set_input_config(InputConfig::default()/* use setters */);Sourcepub fn set_or_clear_input_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<InputConfig>,
pub fn set_or_clear_input_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<InputConfig>,
Sets or clears the value of input_config.
Example
use google_cloud_dialogflow_v2::model::InputConfig;
let x = ConversationDataset::new().set_or_clear_input_config(Some(InputConfig::default()/* use setters */));
let x = ConversationDataset::new().set_or_clear_input_config(None::<InputConfig>);Sourcepub fn set_conversation_info<T>(self, v: T) -> Selfwhere
T: Into<ConversationInfo>,
pub fn set_conversation_info<T>(self, v: T) -> Selfwhere
T: Into<ConversationInfo>,
Sets the value of conversation_info.
Example
use google_cloud_dialogflow_v2::model::ConversationInfo;
let x = ConversationDataset::new().set_conversation_info(ConversationInfo::default()/* use setters */);Sourcepub fn set_or_clear_conversation_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<ConversationInfo>,
pub fn set_or_clear_conversation_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<ConversationInfo>,
Sets or clears the value of conversation_info.
Example
use google_cloud_dialogflow_v2::model::ConversationInfo;
let x = ConversationDataset::new().set_or_clear_conversation_info(Some(ConversationInfo::default()/* use setters */));
let x = ConversationDataset::new().set_or_clear_conversation_info(None::<ConversationInfo>);Sourcepub fn set_conversation_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_conversation_count<T: Into<i64>>(self, v: T) -> Self
Sets the value of conversation_count.
Example
let x = ConversationDataset::new().set_conversation_count(42);Sourcepub fn set_satisfies_pzi<T>(self, v: T) -> Self
pub fn set_satisfies_pzi<T>(self, v: T) -> Self
Sets the value of satisfies_pzi.
Example
let x = ConversationDataset::new().set_satisfies_pzi(true);Sourcepub fn set_or_clear_satisfies_pzi<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_satisfies_pzi<T>(self, v: Option<T>) -> Self
Sets or clears the value of satisfies_pzi.
Example
let x = ConversationDataset::new().set_or_clear_satisfies_pzi(Some(false));
let x = ConversationDataset::new().set_or_clear_satisfies_pzi(None::<bool>);Sourcepub fn set_satisfies_pzs<T>(self, v: T) -> Self
pub fn set_satisfies_pzs<T>(self, v: T) -> Self
Sets the value of satisfies_pzs.
Example
let x = ConversationDataset::new().set_satisfies_pzs(true);Sourcepub fn set_or_clear_satisfies_pzs<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_satisfies_pzs<T>(self, v: Option<T>) -> Self
Sets or clears the value of satisfies_pzs.
Example
let x = ConversationDataset::new().set_or_clear_satisfies_pzs(Some(false));
let x = ConversationDataset::new().set_or_clear_satisfies_pzs(None::<bool>);Trait Implementations
Sourceimpl Clone for ConversationDataset
impl Clone for ConversationDataset
Sourcefn clone(&self) -> ConversationDataset
fn clone(&self) -> ConversationDataset
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ConversationDataset
impl Debug for ConversationDataset
Sourceimpl Default for ConversationDataset
impl Default for ConversationDataset
Sourcefn default() -> ConversationDataset
fn default() -> ConversationDataset
Sourceimpl Message for ConversationDataset
impl Message for ConversationDataset
Sourceimpl PartialEq for ConversationDataset
impl PartialEq for ConversationDataset
impl StructuralPartialEq for ConversationDataset