#[non_exhaustive]pub struct ConversationEvent {
pub conversation: String,
pub type: Type,
pub error_status: Option<Status>,
pub payload: Option<Payload>,
/* private fields */
}agents and answer-records and contexts and conversation-datasets and conversation-models and conversation-profiles and conversations and documents and encryption-spec-service and entity-types and environments and fulfillments and generator-evaluations and generators and intents and knowledge-bases and participants and session-entity-types and sessions and sip-trunks and tools and versions only.Expand description
Represents a notification sent to Pub/Sub subscribers for conversation lifecycle events.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.conversation: StringThe unique identifier of the conversation this notification
refers to.
Format: projects/<Project ID>/conversations/<Conversation ID>.
type: TypeThe type of the event that this notification refers to.
error_status: Option<Status>More detailed information about an error. Only set for type UNRECOVERABLE_ERROR_IN_PHONE_CALL.
payload: Option<Payload>Payload of conversation event.
Implementations
Sourceimpl ConversationEvent
impl ConversationEvent
Sourcepub fn set_conversation<T: Into<String>>(self, v: T) -> Self
pub fn set_conversation<T: Into<String>>(self, v: T) -> Self
Sets the value of conversation.
Example
let x = ConversationEvent::new().set_conversation("example");Sourcepub fn set_type<T: Into<Type>>(self, v: T) -> Self
pub fn set_type<T: Into<Type>>(self, v: T) -> Self
Sets the value of r#type.
Example
use google_cloud_dialogflow_v2::model::conversation_event::Type;
let x0 = ConversationEvent::new().set_type(Type::ConversationStarted);
let x1 = ConversationEvent::new().set_type(Type::ConversationFinished);
let x2 = ConversationEvent::new().set_type(Type::HumanInterventionNeeded);Sourcepub fn set_error_status<T>(self, v: T) -> Self
pub fn set_error_status<T>(self, v: T) -> Self
Sets the value of error_status.
Example
use google_cloud_rpc::model::Status;
let x = ConversationEvent::new().set_error_status(Status::default()/* use setters */);Sourcepub fn set_or_clear_error_status<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_error_status<T>(self, v: Option<T>) -> Self
Sets or clears the value of error_status.
Example
use google_cloud_rpc::model::Status;
let x = ConversationEvent::new().set_or_clear_error_status(Some(Status::default()/* use setters */));
let x = ConversationEvent::new().set_or_clear_error_status(None::<Status>);Sourcepub fn set_payload<T: Into<Option<Payload>>>(self, v: T) -> Self
pub fn set_payload<T: Into<Option<Payload>>>(self, v: T) -> Self
Sets the value of payload.
Note that all the setters affecting payload are mutually
exclusive.
Example
use google_cloud_dialogflow_v2::model::Message;
let x = ConversationEvent::new().set_payload(Some(
google_cloud_dialogflow_v2::model::conversation_event::Payload::NewMessagePayload(Message::default().into())));Sourcepub fn new_message_payload(&self) -> Option<&Box<Message>>
pub fn new_message_payload(&self) -> Option<&Box<Message>>
The value of payload
if it holds a NewMessagePayload, None if the field is not set or
holds a different branch.
Sourcepub fn set_new_message_payload<T: Into<Box<Message>>>(self, v: T) -> Self
pub fn set_new_message_payload<T: Into<Box<Message>>>(self, v: T) -> Self
Sets the value of payload
to hold a NewMessagePayload.
Note that all the setters affecting payload are
mutually exclusive.
Example
use google_cloud_dialogflow_v2::model::Message;
let x = ConversationEvent::new().set_new_message_payload(Message::default()/* use setters */);
assert!(x.new_message_payload().is_some());
assert!(x.new_recognition_result_payload().is_none());Sourcepub fn new_recognition_result_payload(
&self,
) -> Option<&Box<StreamingRecognitionResult>>
pub fn new_recognition_result_payload( &self, ) -> Option<&Box<StreamingRecognitionResult>>
The value of payload
if it holds a NewRecognitionResultPayload, None if the field is not set or
holds a different branch.
Sourcepub fn set_new_recognition_result_payload<T: Into<Box<StreamingRecognitionResult>>>(
self,
v: T,
) -> Self
pub fn set_new_recognition_result_payload<T: Into<Box<StreamingRecognitionResult>>>( self, v: T, ) -> Self
Sets the value of payload
to hold a NewRecognitionResultPayload.
Note that all the setters affecting payload are
mutually exclusive.
Example
use google_cloud_dialogflow_v2::model::StreamingRecognitionResult;
let x = ConversationEvent::new().set_new_recognition_result_payload(StreamingRecognitionResult::default()/* use setters */);
assert!(x.new_recognition_result_payload().is_some());
assert!(x.new_message_payload().is_none());Trait Implementations
Sourceimpl Clone for ConversationEvent
impl Clone for ConversationEvent
Sourcefn clone(&self) -> ConversationEvent
fn clone(&self) -> ConversationEvent
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ConversationEvent
impl Debug for ConversationEvent
Sourceimpl Default for ConversationEvent
impl Default for ConversationEvent
Sourcefn default() -> ConversationEvent
fn default() -> ConversationEvent
Sourceimpl Message for ConversationEvent
impl Message for ConversationEvent
Sourceimpl PartialEq for ConversationEvent
impl PartialEq for ConversationEvent
impl StructuralPartialEq for ConversationEvent