#[non_exhaustive]pub struct DtmfParameters {
pub accepts_dtmf_input: bool,
/* private fields */
}Available on crate feature
participants only.Expand description
The message in the response that indicates the parameters of DTMF.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.accepts_dtmf_input: boolIndicates whether DTMF input can be handled in the next request.
Implementations
Sourceimpl DtmfParameters
impl DtmfParameters
pub fn new() -> Self
Sourcepub fn set_accepts_dtmf_input<T: Into<bool>>(self, v: T) -> Self
pub fn set_accepts_dtmf_input<T: Into<bool>>(self, v: T) -> Self
Sets the value of accepts_dtmf_input.
Example
ⓘ
let x = DtmfParameters::new().set_accepts_dtmf_input(true);Trait Implementations
Sourceimpl Clone for DtmfParameters
impl Clone for DtmfParameters
Sourcefn clone(&self) -> DtmfParameters
fn clone(&self) -> DtmfParameters
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DtmfParameters
impl Debug for DtmfParameters
Sourceimpl Default for DtmfParameters
impl Default for DtmfParameters
Sourcefn default() -> DtmfParameters
fn default() -> DtmfParameters
Returns the “default value” for a type. Read more
Sourceimpl Message for DtmfParameters
impl Message for DtmfParameters
Sourceimpl PartialEq for DtmfParameters
impl PartialEq for DtmfParameters
impl StructuralPartialEq for DtmfParameters