#[non_exhaustive]pub struct EvaluationConfig {
pub datasets: Vec<InputDataset>,
pub model_specific_config: Option<ModelSpecificConfig>,
/* private fields */
}conversation-models only.Expand description
The configuration for model evaluation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.datasets: Vec<InputDataset>Required. Datasets used for evaluation.
model_specific_config: Option<ModelSpecificConfig>Specific configurations for different models in order to do evaluation.
Implementations
Sourceimpl EvaluationConfig
impl EvaluationConfig
Sourcepub fn set_datasets<T, V>(self, v: T) -> Self
pub fn set_datasets<T, V>(self, v: T) -> Self
Sourcepub fn set_model_specific_config<T: Into<Option<ModelSpecificConfig>>>(
self,
v: T,
) -> Self
pub fn set_model_specific_config<T: Into<Option<ModelSpecificConfig>>>( self, v: T, ) -> Self
Sets the value of model_specific_config.
Note that all the setters affecting model_specific_config are mutually
exclusive.
Example
use google_cloud_dialogflow_v2::model::evaluation_config::SmartReplyConfig;
let x = EvaluationConfig::new().set_model_specific_config(Some(
google_cloud_dialogflow_v2::model::evaluation_config::ModelSpecificConfig::SmartReplyConfig(SmartReplyConfig::default().into())));Sourcepub fn smart_reply_config(&self) -> Option<&Box<SmartReplyConfig>>
pub fn smart_reply_config(&self) -> Option<&Box<SmartReplyConfig>>
The value of model_specific_config
if it holds a SmartReplyConfig, None if the field is not set or
holds a different branch.
Sourcepub fn set_smart_reply_config<T: Into<Box<SmartReplyConfig>>>(
self,
v: T,
) -> Self
pub fn set_smart_reply_config<T: Into<Box<SmartReplyConfig>>>( self, v: T, ) -> Self
Sets the value of model_specific_config
to hold a SmartReplyConfig.
Note that all the setters affecting model_specific_config are
mutually exclusive.
Example
use google_cloud_dialogflow_v2::model::evaluation_config::SmartReplyConfig;
let x = EvaluationConfig::new().set_smart_reply_config(SmartReplyConfig::default()/* use setters */);
assert!(x.smart_reply_config().is_some());
assert!(x.smart_compose_config().is_none());Sourcepub fn smart_compose_config(&self) -> Option<&Box<SmartComposeConfig>>
pub fn smart_compose_config(&self) -> Option<&Box<SmartComposeConfig>>
The value of model_specific_config
if it holds a SmartComposeConfig, None if the field is not set or
holds a different branch.
Sourcepub fn set_smart_compose_config<T: Into<Box<SmartComposeConfig>>>(
self,
v: T,
) -> Self
pub fn set_smart_compose_config<T: Into<Box<SmartComposeConfig>>>( self, v: T, ) -> Self
Sets the value of model_specific_config
to hold a SmartComposeConfig.
Note that all the setters affecting model_specific_config are
mutually exclusive.
Example
use google_cloud_dialogflow_v2::model::evaluation_config::SmartComposeConfig;
let x = EvaluationConfig::new().set_smart_compose_config(SmartComposeConfig::default()/* use setters */);
assert!(x.smart_compose_config().is_some());
assert!(x.smart_reply_config().is_none());Trait Implementations
Sourceimpl Clone for EvaluationConfig
impl Clone for EvaluationConfig
Sourcefn clone(&self) -> EvaluationConfig
fn clone(&self) -> EvaluationConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for EvaluationConfig
impl Debug for EvaluationConfig
Sourceimpl Default for EvaluationConfig
impl Default for EvaluationConfig
Sourcefn default() -> EvaluationConfig
fn default() -> EvaluationConfig
Sourceimpl Message for EvaluationConfig
impl Message for EvaluationConfig
Sourceimpl PartialEq for EvaluationConfig
impl PartialEq for EvaluationConfig
impl StructuralPartialEq for EvaluationConfig