#[non_exhaustive]pub struct ExportDocumentRequest {
pub name: String,
pub export_full_content: bool,
pub smart_messaging_partial_update: bool,
pub destination: Option<Destination>,
/* private fields */
}documents only.Expand description
Request message for Documents.ExportDocument.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The name of the document to export.
Format: projects/<Project ID>/locations/<Location ID>/knowledgeBases/<Knowledge Base ID>/documents/<Document ID>.
export_full_content: boolWhen enabled, export the full content of the document including empirical probability.
smart_messaging_partial_update: boolWhen enabled, export the smart messaging allowlist document for partial update.
destination: Option<Destination>Required. The destination for the export.
Implementations
Sourceimpl ExportDocumentRequest
impl ExportDocumentRequest
Sourcepub fn set_export_full_content<T: Into<bool>>(self, v: T) -> Self
pub fn set_export_full_content<T: Into<bool>>(self, v: T) -> Self
Sets the value of export_full_content.
Example
let x = ExportDocumentRequest::new().set_export_full_content(true);Sourcepub fn set_smart_messaging_partial_update<T: Into<bool>>(self, v: T) -> Self
pub fn set_smart_messaging_partial_update<T: Into<bool>>(self, v: T) -> Self
Sets the value of smart_messaging_partial_update.
Example
let x = ExportDocumentRequest::new().set_smart_messaging_partial_update(true);Sourcepub fn set_destination<T: Into<Option<Destination>>>(self, v: T) -> Self
pub fn set_destination<T: Into<Option<Destination>>>(self, v: T) -> Self
Sets the value of destination.
Note that all the setters affecting destination are mutually
exclusive.
Example
use google_cloud_dialogflow_v2::model::GcsDestination;
let x = ExportDocumentRequest::new().set_destination(Some(
google_cloud_dialogflow_v2::model::export_document_request::Destination::GcsDestination(GcsDestination::default().into())));Sourcepub fn gcs_destination(&self) -> Option<&Box<GcsDestination>>
pub fn gcs_destination(&self) -> Option<&Box<GcsDestination>>
The value of destination
if it holds a GcsDestination, None if the field is not set or
holds a different branch.
Sourcepub fn set_gcs_destination<T: Into<Box<GcsDestination>>>(self, v: T) -> Self
pub fn set_gcs_destination<T: Into<Box<GcsDestination>>>(self, v: T) -> Self
Sets the value of destination
to hold a GcsDestination.
Note that all the setters affecting destination are
mutually exclusive.
Example
use google_cloud_dialogflow_v2::model::GcsDestination;
let x = ExportDocumentRequest::new().set_gcs_destination(GcsDestination::default()/* use setters */);
assert!(x.gcs_destination().is_some());Trait Implementations
Sourceimpl Clone for ExportDocumentRequest
impl Clone for ExportDocumentRequest
Sourcefn clone(&self) -> ExportDocumentRequest
fn clone(&self) -> ExportDocumentRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ExportDocumentRequest
impl Debug for ExportDocumentRequest
Sourceimpl Default for ExportDocumentRequest
impl Default for ExportDocumentRequest
Sourcefn default() -> ExportDocumentRequest
fn default() -> ExportDocumentRequest
Sourceimpl Message for ExportDocumentRequest
impl Message for ExportDocumentRequest
Sourceimpl PartialEq for ExportDocumentRequest
impl PartialEq for ExportDocumentRequest
impl StructuralPartialEq for ExportDocumentRequest