#[non_exhaustive]pub struct HumanAgentHandoffConfig {
pub agent_service: Option<AgentService>,
/* private fields */
}conversation-profiles or conversations only.Expand description
Defines the hand off to a live agent, typically on which external agent service provider to connect to a conversation.
Currently, this feature is not general available, please contact Google to get access.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_service: Option<AgentService>Required. Specifies which agent service to connect for human agent handoff.
Implementations
Sourceimpl HumanAgentHandoffConfig
impl HumanAgentHandoffConfig
Sourcepub fn set_agent_service<T: Into<Option<AgentService>>>(self, v: T) -> Self
pub fn set_agent_service<T: Into<Option<AgentService>>>(self, v: T) -> Self
Sets the value of agent_service.
Note that all the setters affecting agent_service are mutually
exclusive.
Example
use google_cloud_dialogflow_v2::model::human_agent_handoff_config::LivePersonConfig;
let x = HumanAgentHandoffConfig::new().set_agent_service(Some(
google_cloud_dialogflow_v2::model::human_agent_handoff_config::AgentService::LivePersonConfig(LivePersonConfig::default().into())));Sourcepub fn live_person_config(&self) -> Option<&Box<LivePersonConfig>>
pub fn live_person_config(&self) -> Option<&Box<LivePersonConfig>>
The value of agent_service
if it holds a LivePersonConfig, None if the field is not set or
holds a different branch.
Sourcepub fn set_live_person_config<T: Into<Box<LivePersonConfig>>>(
self,
v: T,
) -> Self
pub fn set_live_person_config<T: Into<Box<LivePersonConfig>>>( self, v: T, ) -> Self
Sets the value of agent_service
to hold a LivePersonConfig.
Note that all the setters affecting agent_service are
mutually exclusive.
Example
use google_cloud_dialogflow_v2::model::human_agent_handoff_config::LivePersonConfig;
let x = HumanAgentHandoffConfig::new().set_live_person_config(LivePersonConfig::default()/* use setters */);
assert!(x.live_person_config().is_some());
assert!(x.salesforce_live_agent_config().is_none());Sourcepub fn salesforce_live_agent_config(
&self,
) -> Option<&Box<SalesforceLiveAgentConfig>>
pub fn salesforce_live_agent_config( &self, ) -> Option<&Box<SalesforceLiveAgentConfig>>
The value of agent_service
if it holds a SalesforceLiveAgentConfig, None if the field is not set or
holds a different branch.
Sourcepub fn set_salesforce_live_agent_config<T: Into<Box<SalesforceLiveAgentConfig>>>(
self,
v: T,
) -> Self
pub fn set_salesforce_live_agent_config<T: Into<Box<SalesforceLiveAgentConfig>>>( self, v: T, ) -> Self
Sets the value of agent_service
to hold a SalesforceLiveAgentConfig.
Note that all the setters affecting agent_service are
mutually exclusive.
Example
use google_cloud_dialogflow_v2::model::human_agent_handoff_config::SalesforceLiveAgentConfig;
let x = HumanAgentHandoffConfig::new().set_salesforce_live_agent_config(SalesforceLiveAgentConfig::default()/* use setters */);
assert!(x.salesforce_live_agent_config().is_some());
assert!(x.live_person_config().is_none());Trait Implementations
Sourceimpl Clone for HumanAgentHandoffConfig
impl Clone for HumanAgentHandoffConfig
Sourcefn clone(&self) -> HumanAgentHandoffConfig
fn clone(&self) -> HumanAgentHandoffConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for HumanAgentHandoffConfig
impl Debug for HumanAgentHandoffConfig
Sourceimpl Default for HumanAgentHandoffConfig
impl Default for HumanAgentHandoffConfig
Sourcefn default() -> HumanAgentHandoffConfig
fn default() -> HumanAgentHandoffConfig
Sourceimpl Message for HumanAgentHandoffConfig
impl Message for HumanAgentHandoffConfig
Sourceimpl PartialEq for HumanAgentHandoffConfig
impl PartialEq for HumanAgentHandoffConfig
impl StructuralPartialEq for HumanAgentHandoffConfig