#[non_exhaustive]pub struct ListGeneratorEvaluationsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Available on crate feature
generator-evaluations only.Expand description
Request of ListGeneratorEvaluations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The generator resource name. Format:
projects/<Project ID>/locations/<Location ID>/generators/<Generator ID>
Wildcard value - is supported on generator_id to list evaluations across
all generators under same project.
page_size: i32Optional. Maximum number of evaluations to return in a single page. By default 100 and at most 1000.
page_token: StringOptional. The next_page_token value returned from a previous list request.
Implementations
Sourceimpl ListGeneratorEvaluationsRequest
impl ListGeneratorEvaluationsRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListGeneratorEvaluationsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListGeneratorEvaluationsRequest
impl Clone for ListGeneratorEvaluationsRequest
Sourcefn clone(&self) -> ListGeneratorEvaluationsRequest
fn clone(&self) -> ListGeneratorEvaluationsRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListGeneratorEvaluationsRequest
impl Default for ListGeneratorEvaluationsRequest
Sourcefn default() -> ListGeneratorEvaluationsRequest
fn default() -> ListGeneratorEvaluationsRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListGeneratorEvaluationsRequest
impl PartialEq for ListGeneratorEvaluationsRequest
Sourcefn eq(&self, other: &ListGeneratorEvaluationsRequest) -> bool
fn eq(&self, other: &ListGeneratorEvaluationsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListGeneratorEvaluationsRequest