#[non_exhaustive]pub struct ListGeneratorEvaluationsResponse {
pub generator_evaluations: Vec<GeneratorEvaluation>,
pub next_page_token: String,
/* private fields */
}Available on crate feature
generator-evaluations only.Expand description
Response of ListGeneratorEvaluations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.generator_evaluations: Vec<GeneratorEvaluation>The list of evaluations to return.
next_page_token: StringToken to retrieve the next page of results, or empty if there are no more results in the list.
Implementations
Sourceimpl ListGeneratorEvaluationsResponse
impl ListGeneratorEvaluationsResponse
pub fn new() -> Self
Sourcepub fn set_generator_evaluations<T, V>(self, v: T) -> Self
pub fn set_generator_evaluations<T, V>(self, v: T) -> Self
Sets the value of generator_evaluations.
Example
ⓘ
use google_cloud_dialogflow_v2::model::GeneratorEvaluation;
let x = ListGeneratorEvaluationsResponse::new()
.set_generator_evaluations([
GeneratorEvaluation::default()/* use setters */,
GeneratorEvaluation::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListGeneratorEvaluationsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListGeneratorEvaluationsResponse
impl Clone for ListGeneratorEvaluationsResponse
Sourcefn clone(&self) -> ListGeneratorEvaluationsResponse
fn clone(&self) -> ListGeneratorEvaluationsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListGeneratorEvaluationsResponse
impl Default for ListGeneratorEvaluationsResponse
Sourcefn default() -> ListGeneratorEvaluationsResponse
fn default() -> ListGeneratorEvaluationsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListGeneratorEvaluationsResponse
impl PartialEq for ListGeneratorEvaluationsResponse
Sourcefn eq(&self, other: &ListGeneratorEvaluationsResponse) -> bool
fn eq(&self, other: &ListGeneratorEvaluationsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListGeneratorEvaluationsResponse