#[non_exhaustive]pub struct ListMessagesResponse {
pub messages: Vec<Message>,
pub next_page_token: String,
/* private fields */
}Available on crate feature
conversations only.Expand description
The response message for Conversations.ListMessages.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.messages: Vec<Message>The list of messages. There will be a maximum number of items
returned based on the page_size field in the request.
messages is sorted by create_time in descending order.
next_page_token: StringToken to retrieve the next page of results, or empty if there are no more results in the list.
Implementations
Sourceimpl ListMessagesResponse
impl ListMessagesResponse
pub fn new() -> Self
Sourcepub fn set_messages<T, V>(self, v: T) -> Self
pub fn set_messages<T, V>(self, v: T) -> Self
Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListMessagesResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListMessagesResponse
impl Clone for ListMessagesResponse
Sourcefn clone(&self) -> ListMessagesResponse
fn clone(&self) -> ListMessagesResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListMessagesResponse
impl Debug for ListMessagesResponse
Sourceimpl Default for ListMessagesResponse
impl Default for ListMessagesResponse
Sourcefn default() -> ListMessagesResponse
fn default() -> ListMessagesResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for ListMessagesResponse
impl Message for ListMessagesResponse
Sourceimpl PartialEq for ListMessagesResponse
impl PartialEq for ListMessagesResponse
impl StructuralPartialEq for ListMessagesResponse