#[non_exhaustive]pub struct ListSipTrunksResponse {
pub sip_trunks: Vec<SipTrunk>,
pub next_page_token: String,
/* private fields */
}Available on crate feature
sip-trunks only.Expand description
The response message for SipTrunks.ListSipTrunks.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sip_trunks: Vec<SipTrunk>The list of SIP trunks.
next_page_token: StringToken to retrieve the next page of results, or empty if there are no more results in the list.
Implementations
Sourceimpl ListSipTrunksResponse
impl ListSipTrunksResponse
pub fn new() -> Self
Sourcepub fn set_sip_trunks<T, V>(self, v: T) -> Self
pub fn set_sip_trunks<T, V>(self, v: T) -> Self
Sets the value of sip_trunks.
Example
ⓘ
use google_cloud_dialogflow_v2::model::SipTrunk;
let x = ListSipTrunksResponse::new()
.set_sip_trunks([
SipTrunk::default()/* use setters */,
SipTrunk::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListSipTrunksResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListSipTrunksResponse
impl Clone for ListSipTrunksResponse
Sourcefn clone(&self) -> ListSipTrunksResponse
fn clone(&self) -> ListSipTrunksResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListSipTrunksResponse
impl Debug for ListSipTrunksResponse
Sourceimpl Default for ListSipTrunksResponse
impl Default for ListSipTrunksResponse
Sourcefn default() -> ListSipTrunksResponse
fn default() -> ListSipTrunksResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for ListSipTrunksResponse
impl Message for ListSipTrunksResponse
Sourceimpl PartialEq for ListSipTrunksResponse
impl PartialEq for ListSipTrunksResponse
impl StructuralPartialEq for ListSipTrunksResponse