#[non_exhaustive]pub struct OutputAudio {
pub config: Option<OutputAudioConfig>,
pub audio: Bytes,
/* private fields */
}Available on crate feature
participants only.Expand description
Represents the natural language speech audio to be played to the end user.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.config: Option<OutputAudioConfig>Instructs the speech synthesizer how to generate the speech audio.
audio: BytesThe natural language speech audio.
Implementations
Sourceimpl OutputAudio
impl OutputAudio
pub fn new() -> Self
Sourcepub fn set_config<T>(self, v: T) -> Selfwhere
T: Into<OutputAudioConfig>,
pub fn set_config<T>(self, v: T) -> Selfwhere
T: Into<OutputAudioConfig>,
Sourcepub fn set_or_clear_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<OutputAudioConfig>,
pub fn set_or_clear_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<OutputAudioConfig>,