#[non_exhaustive]pub struct Sentiment {
pub score: f32,
pub magnitude: f32,
/* private fields */
}Available on crate features
answer-records or conversations or participants or sessions only.Expand description
The sentiment, such as positive/negative feeling or association, for a unit of analysis, such as the query text. See: https://cloud.google.com/natural-language/docs/basics#interpreting_sentiment_analysis_values for how to interpret the result.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.score: f32Sentiment score between -1.0 (negative sentiment) and 1.0 (positive sentiment).
magnitude: f32A non-negative number in the [0, +inf) range, which represents the absolute magnitude of sentiment, regardless of score (positive or negative).
Implementations