#[non_exhaustive]pub struct SetSuggestionFeatureConfigRequest {
pub conversation_profile: String,
pub participant_role: Role,
pub suggestion_feature_config: Option<SuggestionFeatureConfig>,
/* private fields */
}Available on crate feature
conversation-profiles only.Expand description
The request message for ConversationProfiles.SetSuggestionFeatureConfig.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.conversation_profile: StringRequired. The Conversation Profile to add or update the suggestion feature
config. Format: projects/<Project ID>/locations/<Location ID>/conversationProfiles/<Conversation Profile ID>.
participant_role: RoleRequired. The participant role to add or update the suggestion feature config. Only HUMAN_AGENT or END_USER can be used.
suggestion_feature_config: Option<SuggestionFeatureConfig>Required. The suggestion feature config to add or update.
Implementations
Sourceimpl SetSuggestionFeatureConfigRequest
impl SetSuggestionFeatureConfigRequest
pub fn new() -> Self
Sourcepub fn set_conversation_profile<T: Into<String>>(self, v: T) -> Self
pub fn set_conversation_profile<T: Into<String>>(self, v: T) -> Self
Sets the value of conversation_profile.
Example
ⓘ
let x = SetSuggestionFeatureConfigRequest::new().set_conversation_profile("example");Sourcepub fn set_participant_role<T: Into<Role>>(self, v: T) -> Self
pub fn set_participant_role<T: Into<Role>>(self, v: T) -> Self
Sets the value of participant_role.
Example
ⓘ
use google_cloud_dialogflow_v2::model::participant::Role;
let x0 = SetSuggestionFeatureConfigRequest::new().set_participant_role(Role::HumanAgent);
let x1 = SetSuggestionFeatureConfigRequest::new().set_participant_role(Role::AutomatedAgent);
let x2 = SetSuggestionFeatureConfigRequest::new().set_participant_role(Role::EndUser);Sourcepub fn set_suggestion_feature_config<T>(self, v: T) -> Selfwhere
T: Into<SuggestionFeatureConfig>,
pub fn set_suggestion_feature_config<T>(self, v: T) -> Selfwhere
T: Into<SuggestionFeatureConfig>,
Sets the value of suggestion_feature_config.
Example
ⓘ
use google_cloud_dialogflow_v2::model::human_agent_assistant_config::SuggestionFeatureConfig;
let x = SetSuggestionFeatureConfigRequest::new().set_suggestion_feature_config(SuggestionFeatureConfig::default()/* use setters */);Sourcepub fn set_or_clear_suggestion_feature_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<SuggestionFeatureConfig>,
pub fn set_or_clear_suggestion_feature_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<SuggestionFeatureConfig>,
Sets or clears the value of suggestion_feature_config.
Example
ⓘ
use google_cloud_dialogflow_v2::model::human_agent_assistant_config::SuggestionFeatureConfig;
let x = SetSuggestionFeatureConfigRequest::new().set_or_clear_suggestion_feature_config(Some(SuggestionFeatureConfig::default()/* use setters */));
let x = SetSuggestionFeatureConfigRequest::new().set_or_clear_suggestion_feature_config(None::<SuggestionFeatureConfig>);Trait Implementations
Sourceimpl Clone for SetSuggestionFeatureConfigRequest
impl Clone for SetSuggestionFeatureConfigRequest
Sourcefn clone(&self) -> SetSuggestionFeatureConfigRequest
fn clone(&self) -> SetSuggestionFeatureConfigRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for SetSuggestionFeatureConfigRequest
impl Default for SetSuggestionFeatureConfigRequest
Sourcefn default() -> SetSuggestionFeatureConfigRequest
fn default() -> SetSuggestionFeatureConfigRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for SetSuggestionFeatureConfigRequest
impl PartialEq for SetSuggestionFeatureConfigRequest
Sourcefn eq(&self, other: &SetSuggestionFeatureConfigRequest) -> bool
fn eq(&self, other: &SetSuggestionFeatureConfigRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SetSuggestionFeatureConfigRequest