#[non_exhaustive]pub struct BearerTokenConfig {
pub token: String,
pub secret_version_for_token: String,
/* private fields */
}Available on crate feature
tools only.Expand description
Config for authentication using bearer token.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.token: StringOptional. The text token appended to the text Bearer to the request
Authorization header.
Session parameters
reference
can be used to pass the token dynamically, e.g.
$session.params.parameter-id.
secret_version_for_token: StringOptional. The name of the SecretManager secret version resource storing
the Bearer token. If this field is set, the token field will be
ignored. Format:
projects/{project}/secrets/{secret}/versions/{version}
Implementations
Sourceimpl BearerTokenConfig
impl BearerTokenConfig