#[non_exhaustive]pub struct ServiceAgentAuthConfig {
pub service_agent_auth: ServiceAgentAuth,
/* private fields */
}Available on crate feature
tools only.Expand description
Config for auth using Dialogflow service agent.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.service_agent_auth: ServiceAgentAuthOptional. Indicate the auth token type generated from the Diglogflow service agent. The generated token is sent in the Authorization header.
Implementations
Sourceimpl ServiceAgentAuthConfig
impl ServiceAgentAuthConfig
pub fn new() -> Self
Sourcepub fn set_service_agent_auth<T: Into<ServiceAgentAuth>>(self, v: T) -> Self
pub fn set_service_agent_auth<T: Into<ServiceAgentAuth>>(self, v: T) -> Self
Sets the value of service_agent_auth.
Example
ⓘ
use google_cloud_dialogflow_v2::model::tool::authentication::service_agent_auth_config::ServiceAgentAuth;
let x0 = ServiceAgentAuthConfig::new().set_service_agent_auth(ServiceAgentAuth::IdToken);
let x1 = ServiceAgentAuthConfig::new().set_service_agent_auth(ServiceAgentAuth::AccessToken);Trait Implementations
Sourceimpl Clone for ServiceAgentAuthConfig
impl Clone for ServiceAgentAuthConfig
Sourcefn clone(&self) -> ServiceAgentAuthConfig
fn clone(&self) -> ServiceAgentAuthConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServiceAgentAuthConfig
impl Debug for ServiceAgentAuthConfig
Sourceimpl Default for ServiceAgentAuthConfig
impl Default for ServiceAgentAuthConfig
Sourcefn default() -> ServiceAgentAuthConfig
fn default() -> ServiceAgentAuthConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for ServiceAgentAuthConfig
impl Message for ServiceAgentAuthConfig
Sourceimpl PartialEq for ServiceAgentAuthConfig
impl PartialEq for ServiceAgentAuthConfig
impl StructuralPartialEq for ServiceAgentAuthConfig