#[non_exhaustive]pub enum WebhookState {
Unspecified,
Enabled,
EnabledForSlotFilling,
UnknownValue(UnknownValue),
}answer-records or intents or participants or sessions only.Expand description
Represents the different states that webhooks can be in.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Webhook is disabled in the agent and in the intent.
Enabled
Webhook is enabled in the agent and in the intent.
EnabledForSlotFilling
Webhook is enabled in the agent and in the intent. Also, each slot filling prompt is forwarded to the webhook.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using WebhookState::value or WebhookState::name.
Implementations