#[non_exhaustive]pub struct AgentCoachingInstruction {
pub display_name: String,
pub display_details: String,
pub condition: String,
pub agent_action: String,
pub system_action: String,
pub duplicate_check_result: Option<DuplicateCheckResult>,
pub triggering_event: TriggerEvent,
/* private fields */
}answer-records or conversations or generator-evaluations or generators or participants only.Expand description
Agent Coaching instructions that customer can configure.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.display_name: StringOptional. Display name for the instruction.
display_details: StringOptional. The detailed description of this instruction.
condition: StringOptional. The condition of the instruction. For example, “the customer wants to cancel an order”. If the users want the instruction to be triggered unconditionally, the condition can be empty.
agent_action: StringOptional. The action that human agent should take. For example, “apologize for the slow shipping”. If the users only want to use agent coaching for intent detection, agent_action can be empty
system_action: StringOptional. The action that system should take. For example, “call GetOrderTime with order_number={order number provided by the customer}”. If the users don’t have plugins or don’t want to trigger plugins, the system_action can be empty
duplicate_check_result: Option<DuplicateCheckResult>Output only. Duplication check for the AgentCoachingInstruction.
triggering_event: TriggerEventOptional. The event that should trigger this instruction. If UNSPECIFIED, the instruction triggering will be same as the generator’s trigger_event.
Implementations
Sourceimpl AgentCoachingInstruction
impl AgentCoachingInstruction
pub fn new() -> Self
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
let x = AgentCoachingInstruction::new().set_display_name("example");Sourcepub fn set_display_details<T: Into<String>>(self, v: T) -> Self
pub fn set_display_details<T: Into<String>>(self, v: T) -> Self
Sets the value of display_details.
Example
let x = AgentCoachingInstruction::new().set_display_details("example");Sourcepub fn set_condition<T: Into<String>>(self, v: T) -> Self
pub fn set_condition<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_agent_action<T: Into<String>>(self, v: T) -> Self
pub fn set_agent_action<T: Into<String>>(self, v: T) -> Self
Sets the value of agent_action.
Example
let x = AgentCoachingInstruction::new().set_agent_action("example");Sourcepub fn set_system_action<T: Into<String>>(self, v: T) -> Self
pub fn set_system_action<T: Into<String>>(self, v: T) -> Self
Sets the value of system_action.
Example
let x = AgentCoachingInstruction::new().set_system_action("example");Sourcepub fn set_duplicate_check_result<T>(self, v: T) -> Selfwhere
T: Into<DuplicateCheckResult>,
pub fn set_duplicate_check_result<T>(self, v: T) -> Selfwhere
T: Into<DuplicateCheckResult>,
Sets the value of duplicate_check_result.
Example
use google_cloud_dialogflow_v2::model::agent_coaching_instruction::DuplicateCheckResult;
let x = AgentCoachingInstruction::new().set_duplicate_check_result(DuplicateCheckResult::default()/* use setters */);Sourcepub fn set_or_clear_duplicate_check_result<T>(self, v: Option<T>) -> Selfwhere
T: Into<DuplicateCheckResult>,
pub fn set_or_clear_duplicate_check_result<T>(self, v: Option<T>) -> Selfwhere
T: Into<DuplicateCheckResult>,
Sets or clears the value of duplicate_check_result.
Example
use google_cloud_dialogflow_v2::model::agent_coaching_instruction::DuplicateCheckResult;
let x = AgentCoachingInstruction::new().set_or_clear_duplicate_check_result(Some(DuplicateCheckResult::default()/* use setters */));
let x = AgentCoachingInstruction::new().set_or_clear_duplicate_check_result(None::<DuplicateCheckResult>);Sourcepub fn set_triggering_event<T: Into<TriggerEvent>>(self, v: T) -> Self
pub fn set_triggering_event<T: Into<TriggerEvent>>(self, v: T) -> Self
Sets the value of triggering_event.
Example
use google_cloud_dialogflow_v2::model::agent_coaching_instruction::TriggerEvent;
let x0 = AgentCoachingInstruction::new().set_triggering_event(TriggerEvent::EndOfUtterance);
let x1 = AgentCoachingInstruction::new().set_triggering_event(TriggerEvent::ManualCall);
let x2 = AgentCoachingInstruction::new().set_triggering_event(TriggerEvent::CustomerMessage);Trait Implementations
Sourceimpl Clone for AgentCoachingInstruction
impl Clone for AgentCoachingInstruction
Sourcefn clone(&self) -> AgentCoachingInstruction
fn clone(&self) -> AgentCoachingInstruction
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more