#[non_exhaustive]pub struct CloudConversationDebuggingInfo {Show 18 fields
pub audio_data_chunks: i32,
pub result_end_time_offset: Option<Duration>,
pub first_audio_duration: Option<Duration>,
pub single_utterance: bool,
pub speech_partial_results_end_times: Vec<Duration>,
pub speech_final_results_end_times: Vec<Duration>,
pub partial_responses: i32,
pub speaker_id_passive_latency_ms_offset: i32,
pub bargein_event_triggered: bool,
pub speech_single_utterance: bool,
pub dtmf_partial_results_times: Vec<Duration>,
pub dtmf_final_results_times: Vec<Duration>,
pub single_utterance_end_time_offset: Option<Duration>,
pub no_speech_timeout: Option<Duration>,
pub endpointing_timeout: Option<Duration>,
pub is_input_text: bool,
pub client_half_close_time_offset: Option<Duration>,
pub client_half_close_streaming_time_offset: Option<Duration>,
/* private fields */
}participants or sessions only.Expand description
Cloud conversation info for easier debugging.
It will get populated in StreamingDetectIntentResponse or
StreamingAnalyzeContentResponse when the flag enable_debugging_info is
set to true in corresponding requests.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.audio_data_chunks: i32Number of input audio data chunks in streaming requests.
result_end_time_offset: Option<Duration>Time offset of the end of speech utterance relative to the beginning of the first audio chunk.
first_audio_duration: Option<Duration>Duration of first audio chunk.
single_utterance: boolWhether client used single utterance mode.
speech_partial_results_end_times: Vec<Duration>Time offsets of the speech partial results relative to the beginning of the stream.
speech_final_results_end_times: Vec<Duration>Time offsets of the speech final results (is_final=true) relative to the beginning of the stream.
partial_responses: i32Total number of partial responses.
speaker_id_passive_latency_ms_offset: i32Time offset of Speaker ID stream close time relative to the Speech stream close time in milliseconds. Only meaningful for conversations involving passive verification.
bargein_event_triggered: boolWhether a barge-in event is triggered in this request.
speech_single_utterance: boolWhether speech uses single utterance mode.
dtmf_partial_results_times: Vec<Duration>Time offsets of the DTMF partial results relative to the beginning of the stream.
dtmf_final_results_times: Vec<Duration>Time offsets of the DTMF final results relative to the beginning of the stream.
single_utterance_end_time_offset: Option<Duration>Time offset of the end-of-single-utterance signal relative to the beginning of the stream.
no_speech_timeout: Option<Duration>No speech timeout settings for the stream.
endpointing_timeout: Option<Duration>Speech endpointing timeout settings for the stream.
is_input_text: boolWhether the streaming terminates with an injected text query.
client_half_close_time_offset: Option<Duration>Client half close time in terms of input audio duration.
client_half_close_streaming_time_offset: Option<Duration>Client half close time in terms of API streaming duration.
Implementations
Sourceimpl CloudConversationDebuggingInfo
impl CloudConversationDebuggingInfo
pub fn new() -> Self
Sourcepub fn set_audio_data_chunks<T: Into<i32>>(self, v: T) -> Self
pub fn set_audio_data_chunks<T: Into<i32>>(self, v: T) -> Self
Sets the value of audio_data_chunks.
Example
let x = CloudConversationDebuggingInfo::new().set_audio_data_chunks(42);Sourcepub fn set_result_end_time_offset<T>(self, v: T) -> Self
pub fn set_result_end_time_offset<T>(self, v: T) -> Self
Sets the value of result_end_time_offset.
Example
use wkt::Duration;
let x = CloudConversationDebuggingInfo::new().set_result_end_time_offset(Duration::default()/* use setters */);Sourcepub fn set_or_clear_result_end_time_offset<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_result_end_time_offset<T>(self, v: Option<T>) -> Self
Sets or clears the value of result_end_time_offset.
Example
use wkt::Duration;
let x = CloudConversationDebuggingInfo::new().set_or_clear_result_end_time_offset(Some(Duration::default()/* use setters */));
let x = CloudConversationDebuggingInfo::new().set_or_clear_result_end_time_offset(None::<Duration>);Sourcepub fn set_first_audio_duration<T>(self, v: T) -> Self
pub fn set_first_audio_duration<T>(self, v: T) -> Self
Sets the value of first_audio_duration.
Example
use wkt::Duration;
let x = CloudConversationDebuggingInfo::new().set_first_audio_duration(Duration::default()/* use setters */);Sourcepub fn set_or_clear_first_audio_duration<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_first_audio_duration<T>(self, v: Option<T>) -> Self
Sets or clears the value of first_audio_duration.
Example
use wkt::Duration;
let x = CloudConversationDebuggingInfo::new().set_or_clear_first_audio_duration(Some(Duration::default()/* use setters */));
let x = CloudConversationDebuggingInfo::new().set_or_clear_first_audio_duration(None::<Duration>);Sourcepub fn set_single_utterance<T: Into<bool>>(self, v: T) -> Self
pub fn set_single_utterance<T: Into<bool>>(self, v: T) -> Self
Sets the value of single_utterance.
Example
let x = CloudConversationDebuggingInfo::new().set_single_utterance(true);Sourcepub fn set_speech_partial_results_end_times<T, V>(self, v: T) -> Self
pub fn set_speech_partial_results_end_times<T, V>(self, v: T) -> Self
Sets the value of speech_partial_results_end_times.
Example
use wkt::Duration;
let x = CloudConversationDebuggingInfo::new()
.set_speech_partial_results_end_times([
Duration::default()/* use setters */,
Duration::default()/* use (different) setters */,
]);Sourcepub fn set_speech_final_results_end_times<T, V>(self, v: T) -> Self
pub fn set_speech_final_results_end_times<T, V>(self, v: T) -> Self
Sets the value of speech_final_results_end_times.
Example
use wkt::Duration;
let x = CloudConversationDebuggingInfo::new()
.set_speech_final_results_end_times([
Duration::default()/* use setters */,
Duration::default()/* use (different) setters */,
]);Sourcepub fn set_partial_responses<T: Into<i32>>(self, v: T) -> Self
pub fn set_partial_responses<T: Into<i32>>(self, v: T) -> Self
Sets the value of partial_responses.
Example
let x = CloudConversationDebuggingInfo::new().set_partial_responses(42);Sourcepub fn set_speaker_id_passive_latency_ms_offset<T: Into<i32>>(
self,
v: T,
) -> Self
pub fn set_speaker_id_passive_latency_ms_offset<T: Into<i32>>( self, v: T, ) -> Self
Sets the value of speaker_id_passive_latency_ms_offset.
Example
let x = CloudConversationDebuggingInfo::new().set_speaker_id_passive_latency_ms_offset(42);Sourcepub fn set_bargein_event_triggered<T: Into<bool>>(self, v: T) -> Self
pub fn set_bargein_event_triggered<T: Into<bool>>(self, v: T) -> Self
Sets the value of bargein_event_triggered.
Example
let x = CloudConversationDebuggingInfo::new().set_bargein_event_triggered(true);Sourcepub fn set_speech_single_utterance<T: Into<bool>>(self, v: T) -> Self
pub fn set_speech_single_utterance<T: Into<bool>>(self, v: T) -> Self
Sets the value of speech_single_utterance.
Example
let x = CloudConversationDebuggingInfo::new().set_speech_single_utterance(true);Sourcepub fn set_dtmf_partial_results_times<T, V>(self, v: T) -> Self
pub fn set_dtmf_partial_results_times<T, V>(self, v: T) -> Self
Sets the value of dtmf_partial_results_times.
Example
use wkt::Duration;
let x = CloudConversationDebuggingInfo::new()
.set_dtmf_partial_results_times([
Duration::default()/* use setters */,
Duration::default()/* use (different) setters */,
]);Sourcepub fn set_dtmf_final_results_times<T, V>(self, v: T) -> Self
pub fn set_dtmf_final_results_times<T, V>(self, v: T) -> Self
Sets the value of dtmf_final_results_times.
Example
use wkt::Duration;
let x = CloudConversationDebuggingInfo::new()
.set_dtmf_final_results_times([
Duration::default()/* use setters */,
Duration::default()/* use (different) setters */,
]);Sourcepub fn set_single_utterance_end_time_offset<T>(self, v: T) -> Self
pub fn set_single_utterance_end_time_offset<T>(self, v: T) -> Self
Sets the value of single_utterance_end_time_offset.
Example
use wkt::Duration;
let x = CloudConversationDebuggingInfo::new().set_single_utterance_end_time_offset(Duration::default()/* use setters */);Sourcepub fn set_or_clear_single_utterance_end_time_offset<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_single_utterance_end_time_offset<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of single_utterance_end_time_offset.
Example
use wkt::Duration;
let x = CloudConversationDebuggingInfo::new().set_or_clear_single_utterance_end_time_offset(Some(Duration::default()/* use setters */));
let x = CloudConversationDebuggingInfo::new().set_or_clear_single_utterance_end_time_offset(None::<Duration>);Sourcepub fn set_no_speech_timeout<T>(self, v: T) -> Self
pub fn set_no_speech_timeout<T>(self, v: T) -> Self
Sets the value of no_speech_timeout.
Example
use wkt::Duration;
let x = CloudConversationDebuggingInfo::new().set_no_speech_timeout(Duration::default()/* use setters */);Sourcepub fn set_or_clear_no_speech_timeout<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_no_speech_timeout<T>(self, v: Option<T>) -> Self
Sets or clears the value of no_speech_timeout.
Example
use wkt::Duration;
let x = CloudConversationDebuggingInfo::new().set_or_clear_no_speech_timeout(Some(Duration::default()/* use setters */));
let x = CloudConversationDebuggingInfo::new().set_or_clear_no_speech_timeout(None::<Duration>);Sourcepub fn set_endpointing_timeout<T>(self, v: T) -> Self
pub fn set_endpointing_timeout<T>(self, v: T) -> Self
Sets the value of endpointing_timeout.
Example
use wkt::Duration;
let x = CloudConversationDebuggingInfo::new().set_endpointing_timeout(Duration::default()/* use setters */);Sourcepub fn set_or_clear_endpointing_timeout<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_endpointing_timeout<T>(self, v: Option<T>) -> Self
Sets or clears the value of endpointing_timeout.
Example
use wkt::Duration;
let x = CloudConversationDebuggingInfo::new().set_or_clear_endpointing_timeout(Some(Duration::default()/* use setters */));
let x = CloudConversationDebuggingInfo::new().set_or_clear_endpointing_timeout(None::<Duration>);Sourcepub fn set_is_input_text<T: Into<bool>>(self, v: T) -> Self
pub fn set_is_input_text<T: Into<bool>>(self, v: T) -> Self
Sets the value of is_input_text.
Example
let x = CloudConversationDebuggingInfo::new().set_is_input_text(true);Sourcepub fn set_client_half_close_time_offset<T>(self, v: T) -> Self
pub fn set_client_half_close_time_offset<T>(self, v: T) -> Self
Sets the value of client_half_close_time_offset.
Example
use wkt::Duration;
let x = CloudConversationDebuggingInfo::new().set_client_half_close_time_offset(Duration::default()/* use setters */);Sourcepub fn set_or_clear_client_half_close_time_offset<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_client_half_close_time_offset<T>(self, v: Option<T>) -> Self
Sets or clears the value of client_half_close_time_offset.
Example
use wkt::Duration;
let x = CloudConversationDebuggingInfo::new().set_or_clear_client_half_close_time_offset(Some(Duration::default()/* use setters */));
let x = CloudConversationDebuggingInfo::new().set_or_clear_client_half_close_time_offset(None::<Duration>);Sourcepub fn set_client_half_close_streaming_time_offset<T>(self, v: T) -> Self
pub fn set_client_half_close_streaming_time_offset<T>(self, v: T) -> Self
Sets the value of client_half_close_streaming_time_offset.
Example
use wkt::Duration;
let x = CloudConversationDebuggingInfo::new().set_client_half_close_streaming_time_offset(Duration::default()/* use setters */);Sourcepub fn set_or_clear_client_half_close_streaming_time_offset<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_client_half_close_streaming_time_offset<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of client_half_close_streaming_time_offset.
Example
use wkt::Duration;
let x = CloudConversationDebuggingInfo::new().set_or_clear_client_half_close_streaming_time_offset(Some(Duration::default()/* use setters */));
let x = CloudConversationDebuggingInfo::new().set_or_clear_client_half_close_streaming_time_offset(None::<Duration>);Trait Implementations
Sourceimpl Clone for CloudConversationDebuggingInfo
impl Clone for CloudConversationDebuggingInfo
Sourcefn clone(&self) -> CloudConversationDebuggingInfo
fn clone(&self) -> CloudConversationDebuggingInfo
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for CloudConversationDebuggingInfo
impl Default for CloudConversationDebuggingInfo
Sourcefn default() -> CloudConversationDebuggingInfo
fn default() -> CloudConversationDebuggingInfo
Sourceimpl PartialEq for CloudConversationDebuggingInfo
impl PartialEq for CloudConversationDebuggingInfo
Sourcefn eq(&self, other: &CloudConversationDebuggingInfo) -> bool
fn eq(&self, other: &CloudConversationDebuggingInfo) -> bool
self and other values to be equal, and is used by ==.