#[non_exhaustive]pub struct DetectIntentRequest {
pub session: String,
pub query_params: Option<QueryParameters>,
pub query_input: Option<QueryInput>,
pub output_audio_config: Option<OutputAudioConfig>,
pub output_audio_config_mask: Option<FieldMask>,
pub input_audio: Bytes,
/* private fields */
}sessions only.Expand description
The request to detect user’s intent.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session: StringRequired. The name of the session this query is sent to. Format:
projects/<Project ID>/agent/sessions/<Session ID>, or
projects/<Project ID>/agent/environments/<Environment ID>/users/<User ID>/sessions/<Session ID>. If Environment ID is not specified, we assume
default ‘draft’ environment (Environment ID might be referred to as
environment name at some places). If User ID is not specified, we are
using “-”. It’s up to the API caller to choose an appropriate Session ID
and User Id. They can be a random number or some type of user and session
identifiers (preferably hashed). The length of the Session ID and
User ID must not exceed 36 characters.
For more information, see the API interactions guide.
Note: Always use agent versions for production traffic. See Versions and environments.
query_params: Option<QueryParameters>The parameters of this query.
query_input: Option<QueryInput>Required. The input specification. It can be set to:
-
an audio config which instructs the speech recognizer how to process the speech audio,
-
a conversational query in the form of text, or
-
an event that specifies which intent to trigger.
output_audio_config: Option<OutputAudioConfig>Instructs the speech synthesizer how to generate the output audio. If this field is not set and agent-level speech synthesizer is not configured, no output audio is generated.
output_audio_config_mask: Option<FieldMask>Mask for output_audio_config indicating which settings in this request-level config should override speech synthesizer settings defined at agent-level.
If unspecified or empty, output_audio_config replaces the agent-level config in its entirety.
input_audio: BytesThe natural language speech audio to be processed. This field
should be populated iff query_input is set to an input audio config.
A single request can contain up to 1 minute of speech audio data.
Implementations
Sourceimpl DetectIntentRequest
impl DetectIntentRequest
pub fn new() -> Self
Sourcepub fn set_session<T: Into<String>>(self, v: T) -> Self
pub fn set_session<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_query_params<T>(self, v: T) -> Selfwhere
T: Into<QueryParameters>,
pub fn set_query_params<T>(self, v: T) -> Selfwhere
T: Into<QueryParameters>,
Sets the value of query_params.
Example
use google_cloud_dialogflow_v2::model::QueryParameters;
let x = DetectIntentRequest::new().set_query_params(QueryParameters::default()/* use setters */);Sourcepub fn set_or_clear_query_params<T>(self, v: Option<T>) -> Selfwhere
T: Into<QueryParameters>,
pub fn set_or_clear_query_params<T>(self, v: Option<T>) -> Selfwhere
T: Into<QueryParameters>,
Sets or clears the value of query_params.
Example
use google_cloud_dialogflow_v2::model::QueryParameters;
let x = DetectIntentRequest::new().set_or_clear_query_params(Some(QueryParameters::default()/* use setters */));
let x = DetectIntentRequest::new().set_or_clear_query_params(None::<QueryParameters>);Sourcepub fn set_query_input<T>(self, v: T) -> Selfwhere
T: Into<QueryInput>,
pub fn set_query_input<T>(self, v: T) -> Selfwhere
T: Into<QueryInput>,
Sets the value of query_input.
Example
use google_cloud_dialogflow_v2::model::QueryInput;
let x = DetectIntentRequest::new().set_query_input(QueryInput::default()/* use setters */);Sourcepub fn set_or_clear_query_input<T>(self, v: Option<T>) -> Selfwhere
T: Into<QueryInput>,
pub fn set_or_clear_query_input<T>(self, v: Option<T>) -> Selfwhere
T: Into<QueryInput>,
Sets or clears the value of query_input.
Example
use google_cloud_dialogflow_v2::model::QueryInput;
let x = DetectIntentRequest::new().set_or_clear_query_input(Some(QueryInput::default()/* use setters */));
let x = DetectIntentRequest::new().set_or_clear_query_input(None::<QueryInput>);Sourcepub fn set_output_audio_config<T>(self, v: T) -> Selfwhere
T: Into<OutputAudioConfig>,
pub fn set_output_audio_config<T>(self, v: T) -> Selfwhere
T: Into<OutputAudioConfig>,
Sets the value of output_audio_config.
Example
use google_cloud_dialogflow_v2::model::OutputAudioConfig;
let x = DetectIntentRequest::new().set_output_audio_config(OutputAudioConfig::default()/* use setters */);Sourcepub fn set_or_clear_output_audio_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<OutputAudioConfig>,
pub fn set_or_clear_output_audio_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<OutputAudioConfig>,
Sets or clears the value of output_audio_config.
Example
use google_cloud_dialogflow_v2::model::OutputAudioConfig;
let x = DetectIntentRequest::new().set_or_clear_output_audio_config(Some(OutputAudioConfig::default()/* use setters */));
let x = DetectIntentRequest::new().set_or_clear_output_audio_config(None::<OutputAudioConfig>);Sourcepub fn set_output_audio_config_mask<T>(self, v: T) -> Self
pub fn set_output_audio_config_mask<T>(self, v: T) -> Self
Sets the value of output_audio_config_mask.
Example
use wkt::FieldMask;
let x = DetectIntentRequest::new().set_output_audio_config_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_output_audio_config_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_output_audio_config_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of output_audio_config_mask.
Example
use wkt::FieldMask;
let x = DetectIntentRequest::new().set_or_clear_output_audio_config_mask(Some(FieldMask::default()/* use setters */));
let x = DetectIntentRequest::new().set_or_clear_output_audio_config_mask(None::<FieldMask>);Sourcepub fn set_input_audio<T: Into<Bytes>>(self, v: T) -> Self
pub fn set_input_audio<T: Into<Bytes>>(self, v: T) -> Self
Sets the value of input_audio.
Example
let x = DetectIntentRequest::new().set_input_audio(bytes::Bytes::from_static(b"example"));Trait Implementations
Sourceimpl Clone for DetectIntentRequest
impl Clone for DetectIntentRequest
Sourcefn clone(&self) -> DetectIntentRequest
fn clone(&self) -> DetectIntentRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more